# Copyright 2017 Google Inc. All rights reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import unicode_literals

# flake8: noqa
SCHEMA = {'basePath': '', 'batchPath': 'batch', 'discoveryVersion': 'v1', 'baseUrl': 'https://sheets.googleapis.com/', 'version_module': 'True', 'version': 'v4', 'schemas': {'CopySheetToAnotherSpreadsheetRequest': {'type': 'object', 'id': 'CopySheetToAnotherSpreadsheetRequest', 'description': 'The request to copy a sheet across spreadsheets.', 'properties': {'destinationSpreadsheetId': {'type': 'string', 'description': 'The ID of the spreadsheet to copy the sheet to.'}}}, 'Spreadsheet': {'type': 'object', 'id': 'Spreadsheet', 'description': 'Resource that represents a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The ID of the spreadsheet.\nThis field is read-only.'}, 'spreadsheetUrl': {'type': 'string', 'description': 'The url of the spreadsheet.\nThis field is read-only.'}, 'sheets': {'type': 'array', 'description': 'The sheets that are part of a spreadsheet.', 'items': {'$ref': 'Sheet'}}, 'namedRanges': {'type': 'array', 'description': 'The named ranges defined in a spreadsheet.', 'items': {'$ref': 'NamedRange'}}, 'properties': {'description': 'Overall properties of a spreadsheet.', '$ref': 'SpreadsheetProperties'}}}, 'PivotTable': {'type': 'object', 'id': 'PivotTable', 'description': 'A pivot table.', 'properties': {'rows': {'type': 'array', 'description': 'Each row grouping in the pivot table.', 'items': {'$ref': 'PivotGroup'}}, 'valueLayout': {'description': 'Whether values should be listed horizontally (as columns)\nor vertically (as rows).', 'type': 'string', 'enum': ['HORIZONTAL', 'VERTICAL'], 'enumDescriptions': ['Values are laid out horizontally (as columns).', 'Values are laid out vertically (as rows).']}, 'criteria': {'type': 'object', 'description': "An optional mapping of filters per source column offset.\n\nThe filters will be applied before aggregating data into the pivot table.\nThe map's key is the column offset of the source range that you want to\nfilter, and the value is the criteria for that column.\n\nFor example, if the source was `C10:E15`, a key of `0` will have the filter\nfor column `C`, whereas the key `1` is for column `D`.", 'additionalProperties': {'$ref': 'PivotFilterCriteria'}}, 'source': {'description': 'The range the pivot table is reading data from.', '$ref': 'GridRange'}, 'values': {'type': 'array', 'description': 'A list of values to include in the pivot table.', 'items': {'$ref': 'PivotValue'}}, 'columns': {'type': 'array', 'description': 'Each column grouping in the pivot table.', 'items': {'$ref': 'PivotGroup'}}}}, 'UpdateConditionalFormatRuleResponse': {'type': 'object', 'id': 'UpdateConditionalFormatRuleResponse', 'description': 'The result of updating a conditional format rule.', 'properties': {'newRule': {'description': 'The new rule that replaced the old rule (if replacing),\nor the rule that was moved (if moved)', '$ref': 'ConditionalFormatRule'}, 'newIndex': {'type': 'integer', 'description': 'The index of the new rule.', 'format': 'int32'}, 'oldRule': {'description': 'The old (deleted) rule. Not set if a rule was moved\n(because it is the same as new_rule).', '$ref': 'ConditionalFormatRule'}, 'oldIndex': {'type': 'integer', 'description': 'The old index of the rule. Not set if a rule was replaced\n(because it is the same as new_index).', 'format': 'int32'}}}, 'Padding': {'description': 'The amount of padding around the cell, in pixels.\nWhen updating padding, every field must be specified.', 'id': 'Padding', 'type': 'object', 'properties': {'bottom': {'type': 'integer', 'description': 'The bottom padding of the cell.', 'format': 'int32'}, 'right': {'type': 'integer', 'description': 'The right padding of the cell.', 'format': 'int32'}, 'top': {'type': 'integer', 'description': 'The top padding of the cell.', 'format': 'int32'}, 'left': {'type': 'integer', 'description': 'The left padding of the cell.', 'format': 'int32'}}}, 'UpdateDimensionPropertiesRequest': {'description': 'Updates properties of dimensions within the specified range.', 'id': 'UpdateDimensionPropertiesRequest', 'type': 'object', 'properties': {'range': {'description': 'The rows or columns to update.', '$ref': 'DimensionRange'}, 'properties': {'description': 'Properties to update.', '$ref': 'DimensionProperties'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `properties` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'BasicFilter': {'type': 'object', 'id': 'BasicFilter', 'description': 'The default filter associated with a sheet.', 'properties': {'range': {'description': 'The range the filter covers.', '$ref': 'GridRange'}, 'criteria': {'type': 'object', 'description': "The criteria for showing/hiding values per column.\nThe map's key is the column index, and the value is the criteria for\nthat column.", 'additionalProperties': {'$ref': 'FilterCriteria'}}, 'sortSpecs': {'type': 'array', 'description': 'The sort order per column. Later specifications are used when values\nare equal in the earlier specifications.', 'items': {'$ref': 'SortSpec'}}}}, 'UpdateCellsRequest': {'type': 'object', 'id': 'UpdateCellsRequest', 'description': 'Updates all cells in a range with new data.', 'properties': {'start': {'description': 'The coordinate to start writing data at.\nAny number of rows and columns (including a different number of\ncolumns per row) may be written.', '$ref': 'GridCoordinate'}, 'range': {'description': 'The range to write data to.\n\nIf the data in rows does not cover the entire requested range,\nthe fields matching those set in fields will be cleared.', '$ref': 'GridRange'}, 'rows': {'type': 'array', 'description': 'The data to write.', 'items': {'$ref': 'RowData'}}, 'fields': {'type': 'string', 'description': 'The fields of CellData that should be updated.\nAt least one field must be specified.\nThe root is the CellData; \'row.values.\' should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'BatchGetValuesResponse': {'type': 'object', 'id': 'BatchGetValuesResponse', 'description': 'The response when retrieving more than one range of values in a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The ID of the spreadsheet the data was retrieved from.'}, 'valueRanges': {'type': 'array', 'description': 'The requested values. The order of the ValueRanges is the same as the\norder of the requested ranges.', 'items': {'$ref': 'ValueRange'}}}}, 'TextToColumnsRequest': {'type': 'object', 'id': 'TextToColumnsRequest', 'description': 'Splits a column of text into multiple columns,\nbased on a delimiter in each cell.', 'properties': {'delimiterType': {'description': 'The delimiter type to use.', 'type': 'string', 'enum': ['DELIMITER_TYPE_UNSPECIFIED', 'COMMA', 'SEMICOLON', 'PERIOD', 'SPACE', 'CUSTOM'], 'enumDescriptions': ['Default value. This value must not be used.', '","', '";"', '"."', '" "', 'A custom value as defined in delimiter.']}, 'delimiter': {'type': 'string', 'description': 'The delimiter to use. Used only if delimiterType is\nCUSTOM.'}, 'source': {'description': 'The source data range.  This must span exactly one column.', '$ref': 'GridRange'}}}, 'Borders': {'type': 'object', 'id': 'Borders', 'description': 'The borders of the cell.', 'properties': {'bottom': {'description': 'The bottom border of the cell.', '$ref': 'Border'}, 'right': {'description': 'The right border of the cell.', '$ref': 'Border'}, 'top': {'description': 'The top border of the cell.', '$ref': 'Border'}, 'left': {'description': 'The left border of the cell.', '$ref': 'Border'}}}, 'AddProtectedRangeResponse': {'type': 'object', 'id': 'AddProtectedRangeResponse', 'description': 'The result of adding a new protected range.', 'properties': {'protectedRange': {'description': 'The newly added protected range.', '$ref': 'ProtectedRange'}}}, 'DeleteRangeRequest': {'type': 'object', 'id': 'DeleteRangeRequest', 'description': 'Deletes a range of cells, shifting other cells into the deleted area.', 'properties': {'range': {'description': 'The range of cells to delete.', '$ref': 'GridRange'}, 'shiftDimension': {'description': 'The dimension from which deleted cells will be replaced with.\nIf ROWS, existing cells will be shifted upward to\nreplace the deleted cells. If COLUMNS, existing cells\nwill be shifted left to replace the deleted cells.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}}}, 'InsertDimensionRequest': {'description': 'Inserts rows or columns in a sheet at a particular index.', 'id': 'InsertDimensionRequest', 'type': 'object', 'properties': {'inheritFromBefore': {'type': 'boolean', 'description': 'Whether dimension properties should be extended from the dimensions\nbefore or after the newly inserted dimensions.\nTrue to inherit from the dimensions before (in which case the start\nindex must be greater than 0), and false to inherit from the dimensions\nafter.\n\nFor example, if row index 0 has red background and row index 1\nhas a green background, then inserting 2 rows at index 1 can inherit\neither the green or red background.  If `inheritFromBefore` is true,\nthe two new rows will be red (because the row before the insertion point\nwas red), whereas if `inheritFromBefore` is false, the two new rows will\nbe green (because the row after the insertion point was green).'}, 'range': {'description': 'The dimensions to insert.  Both the start and end indexes must be bounded.', '$ref': 'DimensionRange'}}}, 'GridCoordinate': {'type': 'object', 'id': 'GridCoordinate', 'description': 'A coordinate in a sheet.\nAll indexes are zero-based.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet this coordinate is on.', 'format': 'int32'}, 'rowIndex': {'type': 'integer', 'description': 'The row index of the coordinate.', 'format': 'int32'}, 'columnIndex': {'type': 'integer', 'description': 'The column index of the coordinate.', 'format': 'int32'}}}, 'BasicChartSeries': {'type': 'object', 'id': 'BasicChartSeries', 'description': 'A single series of data in a chart.\nFor example, if charting stock prices over time, multiple series may exist,\none for the "Open Price", "High Price", "Low Price" and "Close Price".', 'properties': {'type': {'description': 'The type of this series. Valid only if the\nchartType is\nCOMBO.\nDifferent types will change the way the series is visualized.\nOnly LINE, AREA,\nand COLUMN are supported.', 'type': 'string', 'enum': ['BASIC_CHART_TYPE_UNSPECIFIED', 'BAR', 'LINE', 'AREA', 'COLUMN', 'SCATTER', 'COMBO'], 'enumDescriptions': ['Default value, do not use.', 'A <a href="/chart/interactive/docs/gallery/barchart">bar chart</a>.', 'A <a href="/chart/interactive/docs/gallery/linechart">line chart</a>.', 'An <a href="/chart/interactive/docs/gallery/areachart">area chart</a>.', 'A <a href="/chart/interactive/docs/gallery/columnchart">column chart</a>.', 'A <a href="/chart/interactive/docs/gallery/scatterchart">scatter chart</a>.', 'A <a href="/chart/interactive/docs/gallery/combochart">combo chart</a>.']}, 'targetAxis': {'description': 'The minor axis that will specify the range of values for this series.\nFor example, if charting stocks over time, the "Volume" series\nmay want to be pinned to the right with the prices pinned to the left,\nbecause the scale of trading volume is different than the scale of\nprices.\nIt is an error to specify an axis that isn\'t a valid minor axis\nfor the chart\'s type.', 'type': 'string', 'enum': ['BASIC_CHART_AXIS_POSITION_UNSPECIFIED', 'BOTTOM_AXIS', 'LEFT_AXIS', 'RIGHT_AXIS'], 'enumDescriptions': ['Default value, do not use.', 'The axis rendered at the bottom of a chart.\nFor most charts, this is the standard major axis.\nFor bar charts, this is a minor axis.', 'The axis rendered at the left of a chart.\nFor most charts, this is a minor axis.\nFor bar charts, this is the standard major axis.', 'The axis rendered at the right of a chart.\nFor most charts, this is a minor axis.\nFor bar charts, this is an unusual major axis.']}, 'series': {'description': 'The data being visualized in this chart series.', '$ref': 'ChartData'}}}, 'AddNamedRangeResponse': {'type': 'object', 'id': 'AddNamedRangeResponse', 'description': 'The result of adding a named range.', 'properties': {'namedRange': {'description': 'The named range to add.', '$ref': 'NamedRange'}}}, 'DimensionRange': {'type': 'object', 'id': 'DimensionRange', 'description': 'A range along a single dimension on a sheet.\nAll indexes are zero-based.\nIndexes are half open: the start index is inclusive\nand the end index is exclusive.\nMissing indexes indicate the range is unbounded on that side.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet this span is on.', 'format': 'int32'}, 'dimension': {'description': 'The dimension of the span.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}, 'endIndex': {'type': 'integer', 'description': 'The end (exclusive) of the span, or not set if unbounded.', 'format': 'int32'}, 'startIndex': {'type': 'integer', 'description': 'The start (inclusive) of the span, or not set if unbounded.', 'format': 'int32'}}}, 'SetBasicFilterRequest': {'type': 'object', 'id': 'SetBasicFilterRequest', 'description': 'Sets the basic filter associated with a sheet.', 'properties': {'filter': {'description': 'The filter to set.', '$ref': 'BasicFilter'}}}, 'UpdateFilterViewRequest': {'type': 'object', 'id': 'UpdateFilterViewRequest', 'description': 'Updates properties of the filter view.', 'properties': {'filter': {'description': 'The new properties of the filter view.', '$ref': 'FilterView'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `filter` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'DeleteBandingRequest': {'type': 'object', 'id': 'DeleteBandingRequest', 'description': 'Removes the banded range with the given ID from the spreadsheet.', 'properties': {'bandedRangeId': {'type': 'integer', 'description': 'The ID of the banded range to delete.', 'format': 'int32'}}}, 'BatchUpdateSpreadsheetRequest': {'type': 'object', 'id': 'BatchUpdateSpreadsheetRequest', 'description': 'The request for updating any aspect of a spreadsheet.', 'properties': {'requests': {'type': 'array', 'description': 'A list of updates to apply to the spreadsheet.', 'items': {'$ref': 'Request'}}, 'responseRanges': {'type': 'array', 'description': "Limits the ranges included in the response spreadsheet.\nMeaningful only if include_spreadsheet_response is 'true'.", 'items': {'type': 'string'}}, 'includeSpreadsheetInResponse': {'type': 'boolean', 'description': 'Determines if the update response should include the spreadsheet\nresource.'}, 'responseIncludeGridData': {'type': 'boolean', 'description': "True if grid data should be returned. Meaningful only if\nif include_spreadsheet_response is 'true'.\nThis parameter is ignored if a field mask was set in the request."}}}, 'EmbeddedChart': {'type': 'object', 'id': 'EmbeddedChart', 'description': 'A chart embedded in a sheet.', 'properties': {'chartId': {'type': 'integer', 'description': 'The ID of the chart.', 'format': 'int32'}, 'position': {'description': 'The position of the chart.', '$ref': 'EmbeddedObjectPosition'}, 'spec': {'description': 'The specification of the chart.', '$ref': 'ChartSpec'}}}, 'AddChartResponse': {'description': 'The result of adding a chart to a spreadsheet.', 'id': 'AddChartResponse', 'type': 'object', 'properties': {'chart': {'description': 'The newly added chart.', '$ref': 'EmbeddedChart'}}}, 'GridData': {'type': 'object', 'id': 'GridData', 'description': 'Data in the grid, as well as metadata about the dimensions.', 'properties': {'startRow': {'type': 'integer', 'description': 'The first row this GridData refers to, zero-based.', 'format': 'int32'}, 'columnMetadata': {'type': 'array', 'description': 'Metadata about the requested columns in the grid, starting with the column\nin start_column.', 'items': {'$ref': 'DimensionProperties'}}, 'rowData': {'type': 'array', 'description': 'The data in the grid, one entry per row,\nstarting with the row in startRow.\nThe values in RowData will correspond to columns starting\nat start_column.', 'items': {'$ref': 'RowData'}}, 'rowMetadata': {'type': 'array', 'description': 'Metadata about the requested rows in the grid, starting with the row\nin start_row.', 'items': {'$ref': 'DimensionProperties'}}, 'startColumn': {'type': 'integer', 'description': 'The first column this GridData refers to, zero-based.', 'format': 'int32'}}}, 'DuplicateSheetResponse': {'type': 'object', 'id': 'DuplicateSheetResponse', 'description': 'The result of duplicating a sheet.', 'properties': {'properties': {'description': 'The properties of the duplicate sheet.', '$ref': 'SheetProperties'}}}, 'MoveDimensionRequest': {'description': 'Moves one or more rows or columns.', 'id': 'MoveDimensionRequest', 'type': 'object', 'properties': {'destinationIndex': {'type': 'integer', 'description': 'The zero-based start index of where to move the source data to,\nbased on the coordinates *before* the source data is removed\nfrom the grid.  Existing data will be shifted down or right\n(depending on the dimension) to make room for the moved dimensions.\nThe source dimensions are removed from the grid, so the\nthe data may end up in a different index than specified.\n\nFor example, given `A1..A5` of `0, 1, 2, 3, 4` and wanting to move\n`"1"` and `"2"` to between `"3"` and `"4"`, the source would be\n`ROWS [1..3)`,and the destination index would be `"4"`\n(the zero-based index of row 5).\nThe end result would be `A1..A5` of `0, 3, 1, 2, 4`.', 'format': 'int32'}, 'source': {'description': 'The source dimensions to move.', '$ref': 'DimensionRange'}}}, 'PivotValue': {'type': 'object', 'id': 'PivotValue', 'description': 'The definition of how a value in a pivot table should be calculated.', 'properties': {'formula': {'type': 'string', 'description': 'A custom formula to calculate the value.  The formula must start\nwith an `=` character.'}, 'sourceColumnOffset': {'type': 'integer', 'description': 'The column offset of the source range that this value reads from.\n\nFor example, if the source was `C10:E15`, a `sourceColumnOffset` of `0`\nmeans this value refers to column `C`, whereas the offset `1` would\nrefer to column `D`.', 'format': 'int32'}, 'summarizeFunction': {'description': 'A function to summarize the value.\nIf formula is set, the only supported values are\nSUM and\nCUSTOM.\nIf sourceColumnOffset is set, then `CUSTOM`\nis not supported.', 'type': 'string', 'enum': ['PIVOT_STANDARD_VALUE_FUNCTION_UNSPECIFIED', 'SUM', 'COUNTA', 'COUNT', 'COUNTUNIQUE', 'AVERAGE', 'MAX', 'MIN', 'MEDIAN', 'PRODUCT', 'STDEV', 'STDEVP', 'VAR', 'VARP', 'CUSTOM'], 'enumDescriptions': ['The default, do not use.', 'Corresponds to the `SUM` function.', 'Corresponds to the `COUNTA` function.', 'Corresponds to the `COUNT` function.', 'Corresponds to the `COUNTUNIQUE` function.', 'Corresponds to the `AVERAGE` function.', 'Corresponds to the `MAX` function.', 'Corresponds to the `MIN` function.', 'Corresponds to the `MEDIAN` function.', 'Corresponds to the `PRODUCT` function.', 'Corresponds to the `STDEV` function.', 'Corresponds to the `STDEVP` function.', 'Corresponds to the `VAR` function.', 'Corresponds to the `VARP` function.', 'Indicates the formula should be used as-is.\nOnly valid if PivotValue.formula was set.']}, 'name': {'type': 'string', 'description': 'A name to use for the value. This is only used if formula was set.\nOtherwise, the column name is used.'}}}, 'Color': {'type': 'object', 'id': 'Color', 'description': 'Represents a color in the RGBA color space. This representation is designed\nfor simplicity of conversion to/from color representations in various\nlanguages over compactness; for example, the fields of this representation\ncan be trivially provided to the constructor of "java.awt.Color" in Java; it\ncan also be trivially provided to UIColor\'s "+colorWithRed:green:blue:alpha"\nmethod in iOS; and, with just a little work, it can be easily formatted into\na CSS "rgba()" string in JavaScript, as well. Here are some examples:\n\nExample (Java):\n\n     import com.google.type.Color;\n\n     // ...\n     public static java.awt.Color fromProto(Color protocolor) {\n       float alpha = protocolor.hasAlpha()\n           ? protocolor.getAlpha().getValue()\n           : 1.0;\n\n       return new java.awt.Color(\n           protocolor.getRed(),\n           protocolor.getGreen(),\n           protocolor.getBlue(),\n           alpha);\n     }\n\n     public static Color toProto(java.awt.Color color) {\n       float red = (float) color.getRed();\n       float green = (float) color.getGreen();\n       float blue = (float) color.getBlue();\n       float denominator = 255.0;\n       Color.Builder resultBuilder =\n           Color\n               .newBuilder()\n               .setRed(red / denominator)\n               .setGreen(green / denominator)\n               .setBlue(blue / denominator);\n       int alpha = color.getAlpha();\n       if (alpha != 255) {\n         result.setAlpha(\n             FloatValue\n                 .newBuilder()\n                 .setValue(((float) alpha) / denominator)\n                 .build());\n       }\n       return resultBuilder.build();\n     }\n     // ...\n\nExample (iOS / Obj-C):\n\n     // ...\n     static UIColor* fromProto(Color* protocolor) {\n        float red = [protocolor red];\n        float green = [protocolor green];\n        float blue = [protocolor blue];\n        FloatValue* alpha_wrapper = [protocolor alpha];\n        float alpha = 1.0;\n        if (alpha_wrapper != nil) {\n          alpha = [alpha_wrapper value];\n        }\n        return [UIColor colorWithRed:red green:green blue:blue alpha:alpha];\n     }\n\n     static Color* toProto(UIColor* color) {\n         CGFloat red, green, blue, alpha;\n         if (![color getRed:&red green:&green blue:&blue alpha:&alpha]) {\n           return nil;\n         }\n         Color* result = [Color alloc] init];\n         [result setRed:red];\n         [result setGreen:green];\n         [result setBlue:blue];\n         if (alpha <= 0.9999) {\n           [result setAlpha:floatWrapperWithValue(alpha)];\n         }\n         [result autorelease];\n         return result;\n    }\n    // ...\n\n Example (JavaScript):\n\n    // ...\n\n    var protoToCssColor = function(rgb_color) {\n       var redFrac = rgb_color.red || 0.0;\n       var greenFrac = rgb_color.green || 0.0;\n       var blueFrac = rgb_color.blue || 0.0;\n       var red = Math.floor(redFrac * 255);\n       var green = Math.floor(greenFrac * 255);\n       var blue = Math.floor(blueFrac * 255);\n\n       if (!(\'alpha\' in rgb_color)) {\n          return rgbToCssColor_(red, green, blue);\n       }\n\n       var alphaFrac = rgb_color.alpha.value || 0.0;\n       var rgbParams = [red, green, blue].join(\',\');\n       return [\'rgba(\', rgbParams, \',\', alphaFrac, \')\'].join(\'\');\n    };\n\n    var rgbToCssColor_ = function(red, green, blue) {\n      var rgbNumber = new Number((red << 16) | (green << 8) | blue);\n      var hexString = rgbNumber.toString(16);\n      var missingZeros = 6 - hexString.length;\n      var resultBuilder = [\'#\'];\n      for (var i = 0; i < missingZeros; i++) {\n         resultBuilder.push(\'0\');\n      }\n      resultBuilder.push(hexString);\n      return resultBuilder.join(\'\');\n    };\n\n    // ...', 'properties': {'blue': {'type': 'number', 'description': 'The amount of blue in the color as a value in the interval [0, 1].', 'format': 'float'}, 'red': {'type': 'number', 'description': 'The amount of red in the color as a value in the interval [0, 1].', 'format': 'float'}, 'alpha': {'type': 'number', 'description': 'The fraction of this color that should be applied to the pixel. That is,\nthe final pixel color is defined by the equation:\n\n  pixel color = alpha * (this color) + (1.0 - alpha) * (background color)\n\nThis means that a value of 1.0 corresponds to a solid color, whereas\na value of 0.0 corresponds to a completely transparent color. This\nuses a wrapper message rather than a simple float scalar so that it is\npossible to distinguish between a default value and the value being unset.\nIf omitted, this color object is to be rendered as a solid color\n(as if the alpha value had been explicitly given with a value of 1.0).', 'format': 'float'}, 'green': {'type': 'number', 'description': 'The amount of green in the color as a value in the interval [0, 1].', 'format': 'float'}}}, 'AddBandingRequest': {'description': 'Adds a new banded range to the spreadsheet.', 'id': 'AddBandingRequest', 'type': 'object', 'properties': {'bandedRange': {'description': 'The banded range to add. The bandedRangeId\nfield is optional; if one is not set, an id will be randomly generated. (It\nis an error to specify the ID of a range that already exists.)', '$ref': 'BandedRange'}}}, 'PivotGroupSortValueBucket': {'type': 'object', 'id': 'PivotGroupSortValueBucket', 'description': 'Information about which values in a pivot group should be used for sorting.', 'properties': {'valuesIndex': {'type': 'integer', 'description': 'The offset in the PivotTable.values list which the values in this\ngrouping should be sorted by.', 'format': 'int32'}, 'buckets': {'type': 'array', 'description': 'Determines the bucket from which values are chosen to sort.\n\nFor example, in a pivot table with one row group & two column groups,\nthe row group can list up to two values. The first value corresponds\nto a value within the first column group, and the second value\ncorresponds to a value in the second column group.  If no values\nare listed, this would indicate that the row should be sorted according\nto the "Grand Total" over the column groups. If a single value is listed,\nthis would correspond to using the "Total" of that bucket.', 'items': {'$ref': 'ExtendedValue'}}}}, 'DeleteDimensionRequest': {'type': 'object', 'id': 'DeleteDimensionRequest', 'description': 'Deletes the dimensions from the sheet.', 'properties': {'range': {'description': 'The dimensions to delete from the sheet.', '$ref': 'DimensionRange'}}}, 'InterpolationPoint': {'type': 'object', 'id': 'InterpolationPoint', 'description': 'A single interpolation point on a gradient conditional format.\nThese pin the gradient color scale according to the color,\ntype and value chosen.', 'properties': {'color': {'description': 'The color this interpolation point should use.', '$ref': 'Color'}, 'type': {'description': 'How the value should be interpreted.', 'type': 'string', 'enum': ['INTERPOLATION_POINT_TYPE_UNSPECIFIED', 'MIN', 'MAX', 'NUMBER', 'PERCENT', 'PERCENTILE'], 'enumDescriptions': ['The default value, do not use.', 'The interpolation point will use the minimum value in the\ncells over the range of the conditional format.', 'The interpolation point will use the maximum value in the\ncells over the range of the conditional format.', 'The interpolation point will use exactly the value in\nInterpolationPoint.value.', 'The interpolation point will be the given percentage over\nall the cells in the range of the conditional format.\nThis is equivalent to NUMBER if the value was:\n`=(MAX(FLATTEN(range)) * (value / 100))\n  + (MIN(FLATTEN(range)) * (1 - (value / 100)))`\n(where errors in the range are ignored when flattening).', 'The interpolation point will be the given percentile\nover all the cells in the range of the conditional format.\nThis is equivalent to NUMBER if the value was:\n`=PERCENTILE(FLATTEN(range), value / 100)`\n(where errors in the range are ignored when flattening).']}, 'value': {'type': 'string', 'description': 'The value this interpolation point uses.  May be a formula.\nUnused if type is MIN or\nMAX.'}}}, 'UpdateSheetPropertiesRequest': {'type': 'object', 'id': 'UpdateSheetPropertiesRequest', 'description': 'Updates properties of the sheet with the specified\nsheetId.', 'properties': {'properties': {'description': 'The properties to update.', '$ref': 'SheetProperties'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `properties` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'ClearBasicFilterRequest': {'description': 'Clears the basic filter, if any exists on the sheet.', 'id': 'ClearBasicFilterRequest', 'type': 'object', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet ID on which the basic filter should be cleared.', 'format': 'int32'}}}, 'Editors': {'type': 'object', 'id': 'Editors', 'description': 'The editors of a protected range.', 'properties': {'groups': {'type': 'array', 'description': 'The email addresses of groups with edit access to the protected range.', 'items': {'type': 'string'}}, 'domainUsersCanEdit': {'type': 'boolean', 'description': "True if anyone in the document's domain has edit access to the protected\nrange.  Domain protection is only supported on documents within a domain."}, 'users': {'type': 'array', 'description': 'The email addresses of users with edit access to the protected range.', 'items': {'type': 'string'}}}}, 'ValueRange': {'type': 'object', 'id': 'ValueRange', 'description': 'Data within a range of the spreadsheet.', 'properties': {'values': {'type': 'array', 'description': 'The data that was read or to be written.  This is an array of arrays,\nthe outer array representing all the data and each inner array\nrepresenting a major dimension. Each item in the inner array\ncorresponds with one cell.\n\nFor output, empty trailing rows and columns will not be included.\n\nFor input, supported value types are: bool, string, and double.\nNull values will be skipped.\nTo set a cell to an empty value, set the string value to an empty string.', 'items': {'type': 'array', 'items': {'type': 'any'}}}, 'range': {'type': 'string', 'description': 'The range the values cover, in A1 notation.\nFor output, this range indicates the entire requested range,\neven though the values will exclude trailing rows and columns.\nWhen appending values, this field represents the range to search for a\ntable, after which values will be appended.'}, 'majorDimension': {'description': 'The major dimension of the values.\n\nFor output, if the spreadsheet data is: `A1=1,B1=2,A2=3,B2=4`,\nthen requesting `range=A1:B2,majorDimension=ROWS` will return\n`[[1,2],[3,4]]`,\nwhereas requesting `range=A1:B2,majorDimension=COLUMNS` will return\n`[[1,3],[2,4]]`.\n\nFor input, with `range=A1:B2,majorDimension=ROWS` then `[[1,2],[3,4]]`\nwill set `A1=1,B1=2,A2=3,B2=4`. With `range=A1:B2,majorDimension=COLUMNS`\nthen `[[1,2],[3,4]]` will set `A1=1,B1=3,A2=2,B2=4`.\n\nWhen writing, if this field is not set, it defaults to ROWS.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}}}, 'DeleteConditionalFormatRuleResponse': {'description': 'The result of deleting a conditional format rule.', 'id': 'DeleteConditionalFormatRuleResponse', 'type': 'object', 'properties': {'rule': {'description': 'The rule that was deleted.', '$ref': 'ConditionalFormatRule'}}}, 'PasteDataRequest': {'type': 'object', 'id': 'PasteDataRequest', 'description': 'Inserts data into the spreadsheet starting at the specified coordinate.', 'properties': {'type': {'description': 'How the data should be pasted.', 'type': 'string', 'enum': ['PASTE_NORMAL', 'PASTE_VALUES', 'PASTE_FORMAT', 'PASTE_NO_BORDERS', 'PASTE_FORMULA', 'PASTE_DATA_VALIDATION', 'PASTE_CONDITIONAL_FORMATTING'], 'enumDescriptions': ['Paste values, formulas, formats, and merges.', 'Paste the values ONLY without formats, formulas, or merges.', 'Paste the format and data validation only.', 'Like PASTE_NORMAL but without borders.', 'Paste the formulas only.', 'Paste the data validation only.', 'Paste the conditional formatting rules only.']}, 'delimiter': {'type': 'string', 'description': 'The delimiter in the data.'}, 'data': {'type': 'string', 'description': 'The data to insert.'}, 'html': {'type': 'boolean', 'description': 'True if the data is HTML.'}, 'coordinate': {'description': 'The coordinate at which the data should start being inserted.', '$ref': 'GridCoordinate'}}}, 'EmbeddedObjectPosition': {'description': 'The position of an embedded object such as a chart.', 'id': 'EmbeddedObjectPosition', 'type': 'object', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet this is on. Set only if the embedded object\nis on its own sheet. Must be non-negative.', 'format': 'int32'}, 'newSheet': {'type': 'boolean', 'description': 'If true, the embedded object will be put on a new sheet whose ID\nis chosen for you. Used only when writing.'}, 'overlayPosition': {'description': 'The position at which the object is overlaid on top of a grid.', '$ref': 'OverlayPosition'}}}, 'RepeatCellRequest': {'type': 'object', 'id': 'RepeatCellRequest', 'description': "Updates all cells in the range to the values in the given Cell object.\nOnly the fields listed in the fields field are updated; others are\nunchanged.\n\nIf writing a cell with a formula, the formula's ranges will automatically\nincrement for each field in the range.\nFor example, if writing a cell with formula `=A1` into range B2:C4,\nB2 would be `=A1`, B3 would be `=A2`, B4 would be `=A3`,\nC2 would be `=B1`, C3 would be `=B2`, C4 would be `=B3`.\n\nTo keep the formula's ranges static, use the `$` indicator.\nFor example, use the formula `=$A$1` to prevent both the row and the\ncolumn from incrementing.", 'properties': {'range': {'description': 'The range to repeat the cell in.', '$ref': 'GridRange'}, 'cell': {'description': 'The data to write.', '$ref': 'CellData'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `cell` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'ProtectedRange': {'description': 'A protected range.', 'id': 'ProtectedRange', 'type': 'object', 'properties': {'editors': {'description': 'The users and groups with edit access to the protected range.\nThis field is only visible to users with edit access to the protected\nrange and the document.\nEditors are not supported with warning_only protection.', '$ref': 'Editors'}, 'warningOnly': {'type': 'boolean', 'description': 'True if this protected range will show a warning when editing.\nWarning-based protection means that every user can edit data in the\nprotected range, except editing will prompt a warning asking the user\nto confirm the edit.\n\nWhen writing: if this field is true, then editors is ignored.\nAdditionally, if this field is changed from true to false and the\n`editors` field is not set (nor included in the field mask), then\nthe editors will be set to all the editors in the document.'}, 'namedRangeId': {'type': 'string', 'description': 'The named range this protected range is backed by, if any.\n\nWhen writing, only one of range or named_range_id\nmay be set.'}, 'unprotectedRanges': {'type': 'array', 'description': 'The list of unprotected ranges within a protected sheet.\nUnprotected ranges are only supported on protected sheets.', 'items': {'$ref': 'GridRange'}}, 'protectedRangeId': {'type': 'integer', 'description': 'The ID of the protected range.\nThis field is read-only.', 'format': 'int32'}, 'description': {'type': 'string', 'description': 'The description of this protected range.'}, 'range': {'description': 'The range that is being protected.\nThe range may be fully unbounded, in which case this is considered\na protected sheet.\n\nWhen writing, only one of range or named_range_id\nmay be set.', '$ref': 'GridRange'}, 'requestingUserCanEdit': {'type': 'boolean', 'description': 'True if the user who requested this protected range can edit the\nprotected area.\nThis field is read-only.'}}}, 'MergeCellsRequest': {'type': 'object', 'id': 'MergeCellsRequest', 'description': 'Merges all cells in the range.', 'properties': {'range': {'description': 'The range of cells to merge.', '$ref': 'GridRange'}, 'mergeType': {'description': 'How the cells should be merged.', 'type': 'string', 'enum': ['MERGE_ALL', 'MERGE_COLUMNS', 'MERGE_ROWS'], 'enumDescriptions': ['Create a single merge from the range', 'Create a merge for each column in the range', 'Create a merge for each row in the range']}}}, 'PivotGroupValueMetadata': {'description': 'Metadata about a value in a pivot grouping.', 'id': 'PivotGroupValueMetadata', 'type': 'object', 'properties': {'collapsed': {'type': 'boolean', 'description': 'True if the data corresponding to the value is collapsed.'}, 'value': {'description': 'The calculated value the metadata corresponds to.\n(Note that formulaValue is not valid,\n because the values will be calculated.)', '$ref': 'ExtendedValue'}}}, 'DeleteEmbeddedObjectRequest': {'description': 'Deletes the embedded object with the given ID.', 'id': 'DeleteEmbeddedObjectRequest', 'type': 'object', 'properties': {'objectId': {'type': 'integer', 'description': 'The ID of the embedded object to delete.', 'format': 'int32'}}}, 'RowData': {'description': 'Data about each cell in a row.', 'id': 'RowData', 'type': 'object', 'properties': {'values': {'type': 'array', 'description': 'The values in the row, one per column.', 'items': {'$ref': 'CellData'}}}}, 'AddProtectedRangeRequest': {'type': 'object', 'id': 'AddProtectedRangeRequest', 'description': 'Adds a new protected range.', 'properties': {'protectedRange': {'description': 'The protected range to be added. The\nprotectedRangeId field is optional; if\none is not set, an id will be randomly generated. (It is an error to\nspecify the ID of a range that already exists.)', '$ref': 'ProtectedRange'}}}, 'BatchUpdateValuesRequest': {'type': 'object', 'id': 'BatchUpdateValuesRequest', 'description': 'The request for updating more than one range of values in a spreadsheet.', 'properties': {'responseDateTimeRenderOption': {'description': 'Determines how dates, times, and durations in the response should be\nrendered. This is ignored if response_value_render_option is\nFORMATTED_VALUE.\nThe default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].', 'type': 'string', 'enum': ['SERIAL_NUMBER', 'FORMATTED_STRING'], 'enumDescriptions': ['Instructs date, time, datetime, and duration fields to be output\nas doubles in "serial number" format, as popularized by Lotus 1-2-3.\nDays are counted from December 31st 1899 and are incremented by 1,\nand times are fractions of a day.  For example, January 1st 1900 at noon\nwould be 1.5, 1 because it\'s 1 day offset from December 31st 1899,\nand .5 because noon is half a day.  February 1st 1900 at 3pm would\nbe 32.625. This correctly treats the year 1900 as not a leap year.', 'Instructs date, time, datetime, and duration fields to be output\nas strings in their given number format (which is dependent\non the spreadsheet locale).']}, 'data': {'type': 'array', 'description': 'The new values to apply to the spreadsheet.', 'items': {'$ref': 'ValueRange'}}, 'valueInputOption': {'description': 'How the input data should be interpreted.', 'type': 'string', 'enum': ['INPUT_VALUE_OPTION_UNSPECIFIED', 'RAW', 'USER_ENTERED'], 'enumDescriptions': ['Default input value. This value must not be used.', 'The values the user has entered will not be parsed and will be stored\nas-is.', 'The values will be parsed as if the user typed them into the UI.\nNumbers will stay as numbers, but strings may be converted to numbers,\ndates, etc. following the same rules that are applied when entering\ntext into a cell via the Google Sheets UI.']}, 'responseValueRenderOption': {'description': 'Determines how values in the response should be rendered.\nThe default render option is ValueRenderOption.FORMATTED_VALUE.', 'type': 'string', 'enum': ['FORMATTED_VALUE', 'UNFORMATTED_VALUE', 'FORMULA'], 'enumDescriptions': ['Values will be calculated & formatted in the reply according to the\ncell\'s formatting.  Formatting is based on the spreadsheet\'s locale,\nnot the requesting user\'s locale.\nFor example, if `A1` is `1.23` and `A2` is `=A1` and formatted as currency,\nthen `A2` would return `"$1.23"`.', 'Values will be calculated, but not formatted in the reply.\nFor example, if `A1` is `1.23` and `A2` is `=A1` and formatted as currency,\nthen `A2` would return the number `1.23`.', 'Values will not be calculated.  The reply will include the formulas.\nFor example, if `A1` is `1.23` and `A2` is `=A1` and formatted as currency,\nthen A2 would return `"=A1"`.']}, 'includeValuesInResponse': {'type': 'boolean', 'description': 'Determines if the update response should include the values\nof the cells that were updated. By default, responses\ndo not include the updated values. The `updatedData` field within\neach of the BatchUpdateValuesResponse.responses will contain\nthe updated values. If the range to write was larger than than the range\nactually written, the response will include all values in the requested\nrange (excluding trailing empty rows and columns).'}}}, 'FindReplaceResponse': {'description': 'The result of the find/replace.', 'id': 'FindReplaceResponse', 'type': 'object', 'properties': {'rowsChanged': {'type': 'integer', 'description': 'The number of rows changed.', 'format': 'int32'}, 'occurrencesChanged': {'type': 'integer', 'description': 'The number of occurrences (possibly multiple within a cell) changed.\nFor example, if replacing `"e"` with `"o"` in `"Google Sheets"`, this would\nbe `"3"` because `"Google Sheets"` -> `"Googlo Shoots"`.', 'format': 'int32'}, 'sheetsChanged': {'type': 'integer', 'description': 'The number of sheets changed.', 'format': 'int32'}, 'formulasChanged': {'type': 'integer', 'description': 'The number of formula cells changed.', 'format': 'int32'}, 'valuesChanged': {'type': 'integer', 'description': 'The number of non-formula cells changed.', 'format': 'int32'}}}, 'ExtendedValue': {'type': 'object', 'id': 'ExtendedValue', 'description': 'The kinds of value that a cell in a spreadsheet can have.', 'properties': {'boolValue': {'type': 'boolean', 'description': 'Represents a boolean value.'}, 'errorValue': {'description': 'Represents an error.\nThis field is read-only.', '$ref': 'ErrorValue'}, 'formulaValue': {'type': 'string', 'description': 'Represents a formula.'}, 'stringValue': {'type': 'string', 'description': 'Represents a string value.\nLeading single quotes are not included. For example, if the user typed\n`\'123` into the UI, this would be represented as a `stringValue` of\n`"123"`.'}, 'numberValue': {'type': 'number', 'description': 'Represents a double value.\nNote: Dates, Times and DateTimes are represented as doubles in\n"serial number" format.', 'format': 'double'}}}, 'BatchUpdateValuesResponse': {'description': 'The response when updating a range of values in a spreadsheet.', 'id': 'BatchUpdateValuesResponse', 'type': 'object', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'totalUpdatedRows': {'type': 'integer', 'description': 'The total number of rows where at least one cell in the row was updated.', 'format': 'int32'}, 'totalUpdatedColumns': {'type': 'integer', 'description': 'The total number of columns where at least one cell in the column was\nupdated.', 'format': 'int32'}, 'responses': {'type': 'array', 'description': 'One UpdateValuesResponse per requested range, in the same order as\nthe requests appeared.', 'items': {'$ref': 'UpdateValuesResponse'}}, 'totalUpdatedCells': {'type': 'integer', 'description': 'The total number of cells updated.', 'format': 'int32'}, 'totalUpdatedSheets': {'type': 'integer', 'description': 'The total number of sheets where at least one cell in the sheet was\nupdated.', 'format': 'int32'}}}, 'SheetProperties': {'description': 'Properties of a sheet.', 'id': 'SheetProperties', 'type': 'object', 'properties': {'tabColor': {'description': 'The color of the tab in the UI.', '$ref': 'Color'}, 'sheetId': {'type': 'integer', 'description': 'The ID of the sheet. Must be non-negative.\nThis field cannot be changed once set.', 'format': 'int32'}, 'rightToLeft': {'type': 'boolean', 'description': 'True if the sheet is an RTL sheet instead of an LTR sheet.'}, 'title': {'type': 'string', 'description': 'The name of the sheet.'}, 'sheetType': {'description': 'The type of sheet. Defaults to GRID.\nThis field cannot be changed once set.', 'type': 'string', 'enum': ['SHEET_TYPE_UNSPECIFIED', 'GRID', 'OBJECT'], 'enumDescriptions': ['Default value, do not use.', 'The sheet is a grid.', 'The sheet has no grid and instead has an object like a chart or image.']}, 'hidden': {'type': 'boolean', 'description': "True if the sheet is hidden in the UI, false if it's visible."}, 'index': {'type': 'integer', 'description': 'The index of the sheet within the spreadsheet.\nWhen adding or updating sheet properties, if this field\nis excluded then the sheet will be added or moved to the end\nof the sheet list. When updating sheet indices or inserting\nsheets, movement is considered in "before the move" indexes.\nFor example, if there were 3 sheets (S1, S2, S3) in order to\nmove S1 ahead of S2 the index would have to be set to 2. A sheet\nindex update request will be ignored if the requested index is\nidentical to the sheets current index or if the requested new\nindex is equal to the current sheet index + 1.', 'format': 'int32'}, 'gridProperties': {'description': 'Additional properties of the sheet if this sheet is a grid.\n(If the sheet is an object sheet, containing a chart or image, then\nthis field will be absent.)\nWhen writing it is an error to set any grid properties on non-grid sheets.', '$ref': 'GridProperties'}}}, 'DimensionProperties': {'type': 'object', 'id': 'DimensionProperties', 'description': 'Properties about a dimension.', 'properties': {'hiddenByFilter': {'type': 'boolean', 'description': 'True if this dimension is being filtered.\nThis field is read-only.'}, 'hiddenByUser': {'type': 'boolean', 'description': 'True if this dimension is explicitly hidden.'}, 'pixelSize': {'type': 'integer', 'description': 'The height (if a row) or width (if a column) of the dimension in pixels.', 'format': 'int32'}}}, 'GradientRule': {'description': 'A rule that applies a gradient color scale format, based on\nthe interpolation points listed. The format of a cell will vary\nbased on its contents as compared to the values of the interpolation\npoints.', 'id': 'GradientRule', 'type': 'object', 'properties': {'maxpoint': {'description': 'The final interpolation point.', '$ref': 'InterpolationPoint'}, 'minpoint': {'description': 'The starting interpolation point.', '$ref': 'InterpolationPoint'}, 'midpoint': {'description': 'An optional midway interpolation point.', '$ref': 'InterpolationPoint'}}}, 'AddSheetResponse': {'description': 'The result of adding a sheet.', 'id': 'AddSheetResponse', 'type': 'object', 'properties': {'properties': {'description': 'The properties of the newly added sheet.', '$ref': 'SheetProperties'}}}, 'SpreadsheetProperties': {'description': 'Properties of a spreadsheet.', 'id': 'SpreadsheetProperties', 'type': 'object', 'properties': {'autoRecalc': {'description': 'The amount of time to wait before volatile functions are recalculated.', 'type': 'string', 'enum': ['RECALCULATION_INTERVAL_UNSPECIFIED', 'ON_CHANGE', 'MINUTE', 'HOUR'], 'enumDescriptions': ['Default value. This value must not be used.', 'Volatile functions are updated on every change.', 'Volatile functions are updated on every change and every minute.', 'Volatile functions are updated on every change and hourly.']}, 'title': {'type': 'string', 'description': 'The title of the spreadsheet.'}, 'locale': {'type': 'string', 'description': 'The locale of the spreadsheet in one of the following formats:\n\n* an ISO 639-1 language code such as `en`\n\n* an ISO 639-2 language code such as `fil`, if no 639-1 code exists\n\n* a combination of the ISO language code and country code, such as `en_US`\n\nNote: when updating this field, not all locales/languages are supported.'}, 'defaultFormat': {'description': "The default format of all cells in the spreadsheet.\nCellData.effectiveFormat will not be set if the\ncell's format is equal to this default format.\nThis field is read-only.", '$ref': 'CellFormat'}, 'timeZone': {'type': 'string', 'description': "The time zone of the spreadsheet, in CLDR format such as\n`America/New_York`. If the time zone isn't recognized, this may\nbe a custom time zone such as `GMT-07:00`."}}}, 'AddSheetRequest': {'type': 'object', 'id': 'AddSheetRequest', 'description': "Adds a new sheet.\nWhen a sheet is added at a given index,\nall subsequent sheets' indexes are incremented.\nTo add an object sheet, use AddChartRequest instead and specify\nEmbeddedObjectPosition.sheetId or\nEmbeddedObjectPosition.newSheet.", 'properties': {'properties': {'description': 'The properties the new sheet should have.\nAll properties are optional.\nThe sheetId field is optional; if one is not\nset, an id will be randomly generated. (It is an error to specify the ID\nof a sheet that already exists.)', '$ref': 'SheetProperties'}}}, 'DeleteProtectedRangeRequest': {'type': 'object', 'id': 'DeleteProtectedRangeRequest', 'description': 'Deletes the protected range with the given ID.', 'properties': {'protectedRangeId': {'type': 'integer', 'description': 'The ID of the protected range to delete.', 'format': 'int32'}}}, 'ChartData': {'type': 'object', 'id': 'ChartData', 'description': 'The data included in a domain or series.', 'properties': {'sourceRange': {'description': 'The source ranges of the data.', '$ref': 'ChartSourceRange'}}}, 'GridRange': {'type': 'object', 'id': 'GridRange', 'description': 'A range on a sheet.\nAll indexes are zero-based.\nIndexes are half open, e.g the start index is inclusive\nand the end index is exclusive -- [start_index, end_index).\nMissing indexes indicate the range is unbounded on that side.\n\nFor example, if `"Sheet1"` is sheet ID 0, then:\n\n  `Sheet1!A1:A1 == sheet_id: 0,\n                  start_row_index: 0, end_row_index: 1,\n                  start_column_index: 0, end_column_index: 1`\n\n  `Sheet1!A3:B4 == sheet_id: 0,\n                  start_row_index: 2, end_row_index: 4,\n                  start_column_index: 0, end_column_index: 2`\n\n  `Sheet1!A:B == sheet_id: 0,\n                start_column_index: 0, end_column_index: 2`\n\n  `Sheet1!A5:B == sheet_id: 0,\n                 start_row_index: 4,\n                 start_column_index: 0, end_column_index: 2`\n\n  `Sheet1 == sheet_id:0`\n\nThe start index must always be less than or equal to the end index.\nIf the start index equals the end index, then the range is empty.\nEmpty ranges are typically not meaningful and are usually rendered in the\nUI as `#REF!`.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet this range is on.', 'format': 'int32'}, 'endColumnIndex': {'type': 'integer', 'description': 'The end column (exclusive) of the range, or not set if unbounded.', 'format': 'int32'}, 'endRowIndex': {'type': 'integer', 'description': 'The end row (exclusive) of the range, or not set if unbounded.', 'format': 'int32'}, 'startRowIndex': {'type': 'integer', 'description': 'The start row (inclusive) of the range, or not set if unbounded.', 'format': 'int32'}, 'startColumnIndex': {'type': 'integer', 'description': 'The start column (inclusive) of the range, or not set if unbounded.', 'format': 'int32'}}}, 'AutoResizeDimensionsRequest': {'type': 'object', 'id': 'AutoResizeDimensionsRequest', 'description': 'Automatically resizes one or more dimensions based on the contents\nof the cells in that dimension.', 'properties': {'dimensions': {'description': 'The dimensions to automatically resize.\nOnly COLUMNS are supported.', '$ref': 'DimensionRange'}}}, 'ClearValuesResponse': {'type': 'object', 'id': 'ClearValuesResponse', 'description': 'The response when clearing a range of values in a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'clearedRange': {'type': 'string', 'description': "The range (in A1 notation) that was cleared.\n(If the request was for an unbounded range or a ranger larger\n than the bounds of the sheet, this will be the actual range\n that was cleared, bounded to the sheet's limits.)"}}}, 'UpdateNamedRangeRequest': {'type': 'object', 'id': 'UpdateNamedRangeRequest', 'description': 'Updates properties of the named range with the specified\nnamedRangeId.', 'properties': {'namedRange': {'description': 'The named range to update with the new properties.', '$ref': 'NamedRange'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `namedRange` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'UpdateBordersRequest': {'description': 'Updates the borders of a range.\nIf a field is not set in the request, that means the border remains as-is.\nFor example, with two subsequent UpdateBordersRequest:\n\n 1. range: A1:A5 `{ top: RED, bottom: WHITE }`\n 2. range: A1:A5 `{ left: BLUE }`\n\nThat would result in A1:A5 having a borders of\n`{ top: RED, bottom: WHITE, left: BLUE }`.\nIf you want to clear a border, explicitly set the style to\nNONE.', 'id': 'UpdateBordersRequest', 'type': 'object', 'properties': {'innerVertical': {'description': 'The vertical border to put within the range.', '$ref': 'Border'}, 'top': {'description': 'The border to put at the top of the range.', '$ref': 'Border'}, 'left': {'description': 'The border to put at the left of the range.', '$ref': 'Border'}, 'bottom': {'description': 'The border to put at the bottom of the range.', '$ref': 'Border'}, 'right': {'description': 'The border to put at the right of the range.', '$ref': 'Border'}, 'range': {'description': 'The range whose borders should be updated.', '$ref': 'GridRange'}, 'innerHorizontal': {'description': 'The horizontal border to put within the range.', '$ref': 'Border'}}}, 'CellFormat': {'description': 'The format of a cell.', 'id': 'CellFormat', 'type': 'object', 'properties': {'wrapStrategy': {'description': 'The wrap strategy for the value in the cell.', 'type': 'string', 'enum': ['WRAP_STRATEGY_UNSPECIFIED', 'OVERFLOW_CELL', 'LEGACY_WRAP', 'CLIP', 'WRAP'], 'enumDescriptions': ['The default value, do not use.', 'Lines that are longer than the cell width will be written in the next\ncell over, so long as that cell is empty. If the next cell over is\nnon-empty, this behaves the same as CLIP. The text will never wrap\nto the next line unless the user manually inserts a new line.\nExample:\n\n    | First sentence. |\n    | Manual newline that is very long. <- Text continues into next cell\n    | Next newline.   |', 'This wrap strategy represents the old Google Sheets wrap strategy where\nwords that are longer than a line are clipped rather than broken. This\nstrategy is not supported on all platforms and is being phased out.\nExample:\n\n    | Cell has a |\n    | loooooooooo| <- Word is clipped.\n    | word.      |', 'Lines that are longer than the cell width will be clipped.\nThe text will never wrap to the next line unless the user manually\ninserts a new line.\nExample:\n\n    | First sentence. |\n    | Manual newline t| <- Text is clipped\n    | Next newline.   |', 'Words that are longer than a line are wrapped at the character level\nrather than clipped.\nExample:\n\n    | Cell has a |\n    | loooooooooo| <- Word is broken.\n    | ong word.  |']}, 'horizontalAlignment': {'description': 'The horizontal alignment of the value in the cell.', 'type': 'string', 'enum': ['HORIZONTAL_ALIGN_UNSPECIFIED', 'LEFT', 'CENTER', 'RIGHT'], 'enumDescriptions': ['The horizontal alignment is not specified. Do not use this.', 'The text is explicitly aligned to the left of the cell.', 'The text is explicitly aligned to the center of the cell.', 'The text is explicitly aligned to the right of the cell.']}, 'hyperlinkDisplayType': {'description': 'How a hyperlink, if it exists, should be displayed in the cell.', 'type': 'string', 'enum': ['HYPERLINK_DISPLAY_TYPE_UNSPECIFIED', 'LINKED', 'PLAIN_TEXT'], 'enumDescriptions': ['The default value: the hyperlink is rendered. Do not use this.', 'A hyperlink should be explicitly rendered.', 'A hyperlink should not be rendered.']}, 'verticalAlignment': {'description': 'The vertical alignment of the value in the cell.', 'type': 'string', 'enum': ['VERTICAL_ALIGN_UNSPECIFIED', 'TOP', 'MIDDLE', 'BOTTOM'], 'enumDescriptions': ['The vertical alignment is not specified.  Do not use this.', 'The text is explicitly aligned to the top of the cell.', 'The text is explicitly aligned to the middle of the cell.', 'The text is explicitly aligned to the bottom of the cell.']}, 'padding': {'description': 'The padding of the cell.', '$ref': 'Padding'}, 'borders': {'description': 'The borders of the cell.', '$ref': 'Borders'}, 'textFormat': {'description': 'The format of the text in the cell (unless overridden by a format run).', '$ref': 'TextFormat'}, 'textDirection': {'description': 'The direction of the text in the cell.', 'type': 'string', 'enum': ['TEXT_DIRECTION_UNSPECIFIED', 'LEFT_TO_RIGHT', 'RIGHT_TO_LEFT'], 'enumDescriptions': ['The text direction is not specified. Do not use this.', 'The text direction of left-to-right was set by the user.', 'The text direction of right-to-left was set by the user.']}, 'numberFormat': {'description': 'A format describing how number values should be represented to the user.', '$ref': 'NumberFormat'}, 'backgroundColor': {'description': 'The background color of the cell.', '$ref': 'Color'}}}, 'Border': {'type': 'object', 'id': 'Border', 'description': 'A border along a cell.', 'properties': {'color': {'description': 'The color of the border.', '$ref': 'Color'}, 'style': {'description': 'The style of the border.', 'type': 'string', 'enum': ['STYLE_UNSPECIFIED', 'DOTTED', 'DASHED', 'SOLID', 'SOLID_MEDIUM', 'SOLID_THICK', 'NONE', 'DOUBLE'], 'enumDescriptions': ['The style is not specified. Do not use this.', 'The border is dotted.', 'The border is dashed.', 'The border is a thin solid line.', 'The border is a medium solid line.', 'The border is a thick solid line.', 'No border.\nUsed only when updating a border in order to erase it.', 'The border is two solid lines.']}, 'width': {'type': 'integer', 'description': 'The width of the border, in pixels.\nDeprecated; the width is determined by the "style" field.', 'format': 'int32'}}}, 'FilterView': {'type': 'object', 'id': 'FilterView', 'description': 'A filter view.', 'properties': {'title': {'type': 'string', 'description': 'The name of the filter view.'}, 'sortSpecs': {'type': 'array', 'description': 'The sort order per column. Later specifications are used when values\nare equal in the earlier specifications.', 'items': {'$ref': 'SortSpec'}}, 'namedRangeId': {'type': 'string', 'description': 'The named range this filter view is backed by, if any.\n\nWhen writing, only one of range or named_range_id\nmay be set.'}, 'range': {'description': 'The range this filter view covers.\n\nWhen writing, only one of range or named_range_id\nmay be set.', '$ref': 'GridRange'}, 'filterViewId': {'type': 'integer', 'description': 'The ID of the filter view.', 'format': 'int32'}, 'criteria': {'type': 'object', 'description': "The criteria for showing/hiding values per column.\nThe map's key is the column index, and the value is the criteria for\nthat column.", 'additionalProperties': {'$ref': 'FilterCriteria'}}}}, 'AutoFillRequest': {'type': 'object', 'id': 'AutoFillRequest', 'description': 'Fills in more data based on existing data.', 'properties': {'sourceAndDestination': {'description': 'The source and destination areas to autofill.\nThis explicitly lists the source of the autofill and where to\nextend that data.', '$ref': 'SourceAndDestination'}, 'range': {'description': 'The range to autofill. This will examine the range and detect\nthe location that has data and automatically fill that data\nin to the rest of the range.', '$ref': 'GridRange'}, 'useAlternateSeries': {'type': 'boolean', 'description': 'True if we should generate data with the "alternate" series.\nThis differs based on the type and amount of source data.'}}}, 'AddBandingResponse': {'description': 'The result of adding a banded range.', 'id': 'AddBandingResponse', 'type': 'object', 'properties': {'bandedRange': {'description': 'The banded range that was added.', '$ref': 'BandedRange'}}}, 'NumberFormat': {'type': 'object', 'id': 'NumberFormat', 'description': 'The number format of a cell.', 'properties': {'type': {'description': 'The type of the number format.\nWhen writing, this field must be set.', 'type': 'string', 'enum': ['NUMBER_FORMAT_TYPE_UNSPECIFIED', 'TEXT', 'NUMBER', 'PERCENT', 'CURRENCY', 'DATE', 'TIME', 'DATE_TIME', 'SCIENTIFIC'], 'enumDescriptions': ['The number format is not specified\nand is based on the contents of the cell.\nDo not explicitly use this.', 'Text formatting, e.g `1000.12`', 'Number formatting, e.g, `1,000.12`', 'Percent formatting, e.g `10.12%`', 'Currency formatting, e.g `$1,000.12`', 'Date formatting, e.g `9/26/2008`', 'Time formatting, e.g `3:59:00 PM`', 'Date+Time formatting, e.g `9/26/08 15:59:00`', 'Scientific number formatting, e.g `1.01E+03`']}, 'pattern': {'type': 'string', 'description': "Pattern string used for formatting.  If not set, a default pattern based on\nthe user's locale will be used if necessary for the given type.\nSee the [Date and Number Formats guide](/sheets/guides/formats) for more\ninformation about the supported patterns."}}}, 'DeleteFilterViewRequest': {'type': 'object', 'id': 'DeleteFilterViewRequest', 'description': 'Deletes a particular filter view.', 'properties': {'filterId': {'type': 'integer', 'description': 'The ID of the filter to delete.', 'format': 'int32'}}}, 'TextFormat': {'type': 'object', 'id': 'TextFormat', 'description': "The format of a run of text in a cell.\nAbsent values indicate that the field isn't specified.", 'properties': {'fontSize': {'type': 'integer', 'description': 'The size of the font.', 'format': 'int32'}, 'foregroundColor': {'description': 'The foreground color of the text.', '$ref': 'Color'}, 'italic': {'type': 'boolean', 'description': 'True if the text is italicized.'}, 'strikethrough': {'type': 'boolean', 'description': 'True if the text has a strikethrough.'}, 'fontFamily': {'type': 'string', 'description': 'The font family.'}, 'bold': {'type': 'boolean', 'description': 'True if the text is bold.'}, 'underline': {'type': 'boolean', 'description': 'True if the text is underlined.'}}}, 'SetDataValidationRequest': {'type': 'object', 'id': 'SetDataValidationRequest', 'description': 'Sets a data validation rule to every cell in the range.\nTo clear validation in a range, call this with no rule specified.', 'properties': {'range': {'description': 'The range the data validation rule should apply to.', '$ref': 'GridRange'}, 'rule': {'description': 'The data validation rule to set on each cell in the range,\nor empty to clear the data validation in the range.', '$ref': 'DataValidationRule'}}}, 'DuplicateFilterViewResponse': {'type': 'object', 'id': 'DuplicateFilterViewResponse', 'description': 'The result of a filter view being duplicated.', 'properties': {'filter': {'description': 'The newly created filter.', '$ref': 'FilterView'}}}, 'SourceAndDestination': {'type': 'object', 'id': 'SourceAndDestination', 'description': 'A combination of a source range and how to extend that source.', 'properties': {'fillLength': {'type': 'integer', 'description': 'The number of rows or columns that data should be filled into.\nPositive numbers expand beyond the last row or last column\nof the source.  Negative numbers expand before the first row\nor first column of the source.', 'format': 'int32'}, 'dimension': {'description': 'The dimension that data should be filled into.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}, 'source': {'description': 'The location of the data to use as the source of the autofill.', '$ref': 'GridRange'}}}, 'CopyPasteRequest': {'type': 'object', 'id': 'CopyPasteRequest', 'description': 'Copies data from the source to the destination.', 'properties': {'pasteOrientation': {'description': 'How that data should be oriented when pasting.', 'type': 'string', 'enum': ['NORMAL', 'TRANSPOSE'], 'enumDescriptions': ['Paste normally.', 'Paste transposed, where all rows become columns and vice versa.']}, 'pasteType': {'description': 'What kind of data to paste.', 'type': 'string', 'enum': ['PASTE_NORMAL', 'PASTE_VALUES', 'PASTE_FORMAT', 'PASTE_NO_BORDERS', 'PASTE_FORMULA', 'PASTE_DATA_VALIDATION', 'PASTE_CONDITIONAL_FORMATTING'], 'enumDescriptions': ['Paste values, formulas, formats, and merges.', 'Paste the values ONLY without formats, formulas, or merges.', 'Paste the format and data validation only.', 'Like PASTE_NORMAL but without borders.', 'Paste the formulas only.', 'Paste the data validation only.', 'Paste the conditional formatting rules only.']}, 'source': {'description': 'The source range to copy.', '$ref': 'GridRange'}, 'destination': {'description': "The location to paste to. If the range covers a span that's\na multiple of the source's height or width, then the\ndata will be repeated to fill in the destination range.\nIf the range is smaller than the source range, the entire\nsource data will still be copied (beyond the end of the destination range).", '$ref': 'GridRange'}}}, 'BooleanCondition': {'description': 'A condition that can evaluate to true or false.\nBooleanConditions are used by conditional formatting,\ndata validation, and the criteria in filters.', 'id': 'BooleanCondition', 'type': 'object', 'properties': {'values': {'type': 'array', 'description': 'The values of the condition. The number of supported values depends\non the condition type.  Some support zero values,\nothers one or two values,\nand ConditionType.ONE_OF_LIST supports an arbitrary number of values.', 'items': {'$ref': 'ConditionValue'}}, 'type': {'description': 'The type of condition.', 'type': 'string', 'enum': ['CONDITION_TYPE_UNSPECIFIED', 'NUMBER_GREATER', 'NUMBER_GREATER_THAN_EQ', 'NUMBER_LESS', 'NUMBER_LESS_THAN_EQ', 'NUMBER_EQ', 'NUMBER_NOT_EQ', 'NUMBER_BETWEEN', 'NUMBER_NOT_BETWEEN', 'TEXT_CONTAINS', 'TEXT_NOT_CONTAINS', 'TEXT_STARTS_WITH', 'TEXT_ENDS_WITH', 'TEXT_EQ', 'TEXT_IS_EMAIL', 'TEXT_IS_URL', 'DATE_EQ', 'DATE_BEFORE', 'DATE_AFTER', 'DATE_ON_OR_BEFORE', 'DATE_ON_OR_AFTER', 'DATE_BETWEEN', 'DATE_NOT_BETWEEN', 'DATE_IS_VALID', 'ONE_OF_RANGE', 'ONE_OF_LIST', 'BLANK', 'NOT_BLANK', 'CUSTOM_FORMULA'], 'enumDescriptions': ['The default value, do not use.', "The cell's value must be greater than the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be greater than or equal to the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be less than the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be less than or equal to the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be equal to the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be not equal to the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be between the two condition values.\nSupported by data validation, conditional formatting and filters.\nRequires exactly two ConditionValues.", "The cell's value must not be between the two condition values.\nSupported by data validation, conditional formatting and filters.\nRequires exactly two ConditionValues.", "The cell's value must contain the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must not contain the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must start with the condition's value.\nSupported by conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must end with the condition's value.\nSupported by conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be exactly the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be a valid email address.\nSupported by data validation.\nRequires no ConditionValues.", "The cell's value must be a valid URL.\nSupported by data validation.\nRequires no ConditionValues.", "The cell's value must be the same date as the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue.", "The cell's value must be before the date of the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue\nthat may be a relative date.", "The cell's value must be after the date of the condition's value.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue\nthat may be a relative date.", "The cell's value must be on or before the date of the condition's value.\nSupported by data validation.\nRequires a single ConditionValue\nthat may be a relative date.", "The cell's value must be on or after the date of the condition's value.\nSupported by data validation.\nRequires a single ConditionValue\nthat may be a relative date.", "The cell's value must be between the dates of the two condition values.\nSupported by data validation.\nRequires exactly two ConditionValues.", "The cell's value must be outside the dates of the two condition values.\nSupported by data validation.\nRequires exactly two ConditionValues.", "The cell's value must be a date.\nSupported by data validation.\nRequires no ConditionValues.", "The cell's value must be listed in the grid in condition value's range.\nSupported by data validation.\nRequires a single ConditionValue,\nand the value must be a valid range in A1 notation.", "The cell's value must in the list of condition values.\nSupported by data validation.\nSupports any number of condition values,\none per item in the list.\nFormulas are not supported in the values.", "The cell's value must be empty.\nSupported by conditional formatting and filters.\nRequires no ConditionValues.", "The cell's value must not be empty.\nSupported by conditional formatting and filters.\nRequires no ConditionValues.", "The condition's formula must evaluate to true.\nSupported by data validation, conditional formatting and filters.\nRequires a single ConditionValue."]}}}, 'BasicChartAxis': {'type': 'object', 'id': 'BasicChartAxis', 'description': 'An axis of the chart.\nA chart may not have more than one axis per\naxis position.', 'properties': {'format': {'description': 'The format of the title.\nOnly valid if the axis is not associated with the domain.', '$ref': 'TextFormat'}, 'position': {'description': 'The position of this axis.', 'type': 'string', 'enum': ['BASIC_CHART_AXIS_POSITION_UNSPECIFIED', 'BOTTOM_AXIS', 'LEFT_AXIS', 'RIGHT_AXIS'], 'enumDescriptions': ['Default value, do not use.', 'The axis rendered at the bottom of a chart.\nFor most charts, this is the standard major axis.\nFor bar charts, this is a minor axis.', 'The axis rendered at the left of a chart.\nFor most charts, this is a minor axis.\nFor bar charts, this is the standard major axis.', 'The axis rendered at the right of a chart.\nFor most charts, this is a minor axis.\nFor bar charts, this is an unusual major axis.']}, 'title': {'type': 'string', 'description': 'The title of this axis. If set, this overrides any title inferred\nfrom headers of the data.'}}}, 'Sheet': {'type': 'object', 'id': 'Sheet', 'description': 'A sheet in a spreadsheet.', 'properties': {'charts': {'type': 'array', 'description': 'The specifications of every chart on this sheet.', 'items': {'$ref': 'EmbeddedChart'}}, 'protectedRanges': {'type': 'array', 'description': 'The protected ranges in this sheet.', 'items': {'$ref': 'ProtectedRange'}}, 'properties': {'description': 'The properties of the sheet.', '$ref': 'SheetProperties'}, 'data': {'type': 'array', 'description': 'Data in the grid, if this is a grid sheet.\nThe number of GridData objects returned is dependent on the number of\nranges requested on this sheet. For example, if this is representing\n`Sheet1`, and the spreadsheet was requested with ranges\n`Sheet1!A1:C10` and `Sheet1!D15:E20`, then the first GridData will have a\nstartRow/startColumn of `0`,\nwhile the second one will have `startRow 14` (zero-based row 15),\nand `startColumn 3` (zero-based column D).', 'items': {'$ref': 'GridData'}}, 'filterViews': {'type': 'array', 'description': 'The filter views in this sheet.', 'items': {'$ref': 'FilterView'}}, 'bandedRanges': {'type': 'array', 'description': 'The banded (i.e. alternating colors) ranges on this sheet.', 'items': {'$ref': 'BandedRange'}}, 'conditionalFormats': {'type': 'array', 'description': 'The conditional format rules in this sheet.', 'items': {'$ref': 'ConditionalFormatRule'}}, 'basicFilter': {'description': 'The filter on this sheet, if any.', '$ref': 'BasicFilter'}, 'merges': {'type': 'array', 'description': 'The ranges that are merged together.', 'items': {'$ref': 'GridRange'}}}}, 'UpdateChartSpecRequest': {'type': 'object', 'id': 'UpdateChartSpecRequest', 'description': "Updates a chart's specifications.\n(This does not move or resize a chart. To move or resize a chart, use\n UpdateEmbeddedObjectPositionRequest.)", 'properties': {'chartId': {'type': 'integer', 'description': 'The ID of the chart to update.', 'format': 'int32'}, 'spec': {'description': 'The specification to apply to the chart.', '$ref': 'ChartSpec'}}}, 'ConditionalFormatRule': {'type': 'object', 'id': 'ConditionalFormatRule', 'description': 'A rule describing a conditional format.', 'properties': {'ranges': {'type': 'array', 'description': 'The ranges that will be formatted if the condition is true.\nAll the ranges must be on the same grid.', 'items': {'$ref': 'GridRange'}}, 'gradientRule': {'description': 'The formatting will vary based on the gradients in the rule.', '$ref': 'GradientRule'}, 'booleanRule': {'description': 'The formatting is either "on" or "off" according to the rule.', '$ref': 'BooleanRule'}}}, 'Response': {'type': 'object', 'id': 'Response', 'description': 'A single response from an update.', 'properties': {'updateConditionalFormatRule': {'description': 'A reply from updating a conditional format rule.', '$ref': 'UpdateConditionalFormatRuleResponse'}, 'addBanding': {'description': 'A reply from adding a banded range.', '$ref': 'AddBandingResponse'}, 'duplicateSheet': {'description': 'A reply from duplicating a sheet.', '$ref': 'DuplicateSheetResponse'}, 'addSheet': {'description': 'A reply from adding a sheet.', '$ref': 'AddSheetResponse'}, 'addProtectedRange': {'description': 'A reply from adding a protected range.', '$ref': 'AddProtectedRangeResponse'}, 'duplicateFilterView': {'description': 'A reply from duplicating a filter view.', '$ref': 'DuplicateFilterViewResponse'}, 'findReplace': {'description': 'A reply from doing a find/replace.', '$ref': 'FindReplaceResponse'}, 'updateEmbeddedObjectPosition': {'description': "A reply from updating an embedded object's position.", '$ref': 'UpdateEmbeddedObjectPositionResponse'}, 'addNamedRange': {'description': 'A reply from adding a named range.', '$ref': 'AddNamedRangeResponse'}, 'addFilterView': {'description': 'A reply from adding a filter view.', '$ref': 'AddFilterViewResponse'}, 'deleteConditionalFormatRule': {'description': 'A reply from deleting a conditional format rule.', '$ref': 'DeleteConditionalFormatRuleResponse'}, 'addChart': {'description': 'A reply from adding a chart.', '$ref': 'AddChartResponse'}}}, 'PieChartSpec': {'type': 'object', 'id': 'PieChartSpec', 'description': 'A <a href="/chart/interactive/docs/gallery/piechart">pie chart</a>.', 'properties': {'domain': {'description': 'The data that covers the domain of the pie chart.', '$ref': 'ChartData'}, 'threeDimensional': {'type': 'boolean', 'description': 'True if the pie is three dimensional.'}, 'pieHole': {'type': 'number', 'description': 'The size of the hole in the pie chart.', 'format': 'double'}, 'legendPosition': {'description': 'Where the legend of the pie chart should be drawn.', 'type': 'string', 'enum': ['PIE_CHART_LEGEND_POSITION_UNSPECIFIED', 'BOTTOM_LEGEND', 'LEFT_LEGEND', 'RIGHT_LEGEND', 'TOP_LEGEND', 'NO_LEGEND', 'LABELED_LEGEND'], 'enumDescriptions': ['Default value, do not use.', 'The legend is rendered on the bottom of the chart.', 'The legend is rendered on the left of the chart.', 'The legend is rendered on the right of the chart.', 'The legend is rendered on the top of the chart.', 'No legend is rendered.', 'Each pie slice has a label attached to it.']}, 'series': {'description': 'The data that covers the one and only series of the pie chart.', '$ref': 'ChartData'}}}, 'AppendDimensionRequest': {'type': 'object', 'id': 'AppendDimensionRequest', 'description': 'Appends rows or columns to the end of a sheet.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet to append rows or columns to.', 'format': 'int32'}, 'dimension': {'description': 'Whether rows or columns should be appended.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}, 'length': {'type': 'integer', 'description': 'The number of rows or columns to append.', 'format': 'int32'}}}, 'AppendValuesResponse': {'type': 'object', 'id': 'AppendValuesResponse', 'description': 'The response when updating a range of values in a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'tableRange': {'type': 'string', 'description': 'The range (in A1 notation) of the table that values are being appended to\n(before the values were appended).\nEmpty if no table was found.'}, 'updates': {'description': 'Information about the updates that were applied.', '$ref': 'UpdateValuesResponse'}}}, 'UpdateSpreadsheetPropertiesRequest': {'type': 'object', 'id': 'UpdateSpreadsheetPropertiesRequest', 'description': 'Updates properties of a spreadsheet.', 'properties': {'properties': {'description': 'The properties to update.', '$ref': 'SpreadsheetProperties'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root \'properties\' is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'UpdateEmbeddedObjectPositionResponse': {'type': 'object', 'id': 'UpdateEmbeddedObjectPositionResponse', 'description': "The result of updating an embedded object's position.", 'properties': {'position': {'description': 'The new position of the embedded object.', '$ref': 'EmbeddedObjectPosition'}}}, 'FindReplaceRequest': {'type': 'object', 'id': 'FindReplaceRequest', 'description': 'Finds and replaces data in cells over a range, sheet, or all sheets.', 'properties': {'matchEntireCell': {'type': 'boolean', 'description': 'True if the find value should match the entire cell.'}, 'sheetId': {'type': 'integer', 'description': 'The sheet to find/replace over.', 'format': 'int32'}, 'allSheets': {'type': 'boolean', 'description': 'True to find/replace over all sheets.'}, 'matchCase': {'type': 'boolean', 'description': 'True if the search is case sensitive.'}, 'searchByRegex': {'type': 'boolean', 'description': 'True if the find value is a regex.\nThe regular expression and replacement should follow Java regex rules\nat https://docs.oracle.com/javase/8/docs/api/java/util/regex/Pattern.html.\nThe replacement string is allowed to refer to capturing groups.\nFor example, if one cell has the contents `"Google Sheets"` and another\nhas `"Google Docs"`, then searching for `"o.* (.*)"` with a replacement of\n`"$1 Rocks"` would change the contents of the cells to\n`"GSheets Rocks"` and `"GDocs Rocks"` respectively.'}, 'range': {'description': 'The range to find/replace over.', '$ref': 'GridRange'}, 'includeFormulas': {'type': 'boolean', 'description': 'True if the search should include cells with formulas.\nFalse to skip cells with formulas.'}, 'find': {'type': 'string', 'description': 'The value to search.'}, 'replacement': {'type': 'string', 'description': 'The value to use as the replacement.'}}}, 'CellData': {'description': 'Data about a specific cell.', 'id': 'CellData', 'type': 'object', 'properties': {'pivotTable': {'description': 'A pivot table anchored at this cell. The size of pivot table itself\nis computed dynamically based on its data, grouping, filters, values,\netc. Only the top-left cell of the pivot table contains the pivot table\ndefinition. The other cells will contain the calculated values of the\nresults of the pivot in their effective_value fields.', '$ref': 'PivotTable'}, 'effectiveValue': {'description': 'The effective value of the cell. For cells with formulas, this will be\nthe calculated value.  For cells with literals, this will be\nthe same as the user_entered_value.\nThis field is read-only.', '$ref': 'ExtendedValue'}, 'hyperlink': {'type': 'string', 'description': 'A hyperlink this cell points to, if any.\nThis field is read-only.  (To set it, use a `=HYPERLINK` formula.)'}, 'formattedValue': {'type': 'string', 'description': "The formatted value of the cell.\nThis is the value as it's shown to the user.\nThis field is read-only."}, 'userEnteredValue': {'description': "The value the user entered in the cell. e.g, `1234`, `'Hello'`, or `=NOW()`\nNote: Dates, Times and DateTimes are represented as doubles in\nserial number format.", '$ref': 'ExtendedValue'}, 'effectiveFormat': {'description': 'The effective format being used by the cell.\nThis includes the results of applying any conditional formatting and,\nif the cell contains a formula, the computed number format.\nIf the effective format is the default format, effective format will\nnot be written.\nThis field is read-only.', '$ref': 'CellFormat'}, 'textFormatRuns': {'type': 'array', 'description': 'Runs of rich text applied to subsections of the cell.  Runs are only valid\non user entered strings, not formulas, bools, or numbers.\nRuns start at specific indexes in the text and continue until the next\nrun. Properties of a run will continue unless explicitly changed\nin a subsequent run (and properties of the first run will continue\nthe properties of the cell unless explicitly changed).\n\nWhen writing, the new runs will overwrite any prior runs.  When writing a\nnew user_entered_value, previous runs will be erased.', 'items': {'$ref': 'TextFormatRun'}}, 'dataValidation': {'description': 'A data validation rule on the cell, if any.\n\nWhen writing, the new data validation rule will overwrite any prior rule.', '$ref': 'DataValidationRule'}, 'note': {'type': 'string', 'description': 'Any note on the cell.'}, 'userEnteredFormat': {'description': 'The format the user entered for the cell.\n\nWhen writing, the new format will be merged with the existing format.', '$ref': 'CellFormat'}}}, 'BatchClearValuesRequest': {'description': 'The request for clearing more than one range of values in a spreadsheet.', 'id': 'BatchClearValuesRequest', 'type': 'object', 'properties': {'ranges': {'type': 'array', 'description': 'The ranges to clear, in A1 notation.', 'items': {'type': 'string'}}}}, 'BatchClearValuesResponse': {'type': 'object', 'id': 'BatchClearValuesResponse', 'description': 'The response when updating a range of values in a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'clearedRanges': {'type': 'array', 'description': "The ranges that were cleared, in A1 notation.\n(If the requests were for an unbounded range or a ranger larger\n than the bounds of the sheet, this will be the actual ranges\n that were cleared, bounded to the sheet's limits.)", 'items': {'type': 'string'}}}}, 'InsertRangeRequest': {'type': 'object', 'id': 'InsertRangeRequest', 'description': 'Inserts cells into a range, shifting the existing cells over or down.', 'properties': {'range': {'description': 'The range to insert new cells into.', '$ref': 'GridRange'}, 'shiftDimension': {'description': 'The dimension which will be shifted when inserting cells.\nIf ROWS, existing cells will be shifted down.\nIf COLUMNS, existing cells will be shifted right.', 'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'enumDescriptions': ['The default value, do not use.', 'Operates on the rows of a sheet.', 'Operates on the columns of a sheet.']}}}, 'DuplicateFilterViewRequest': {'type': 'object', 'id': 'DuplicateFilterViewRequest', 'description': 'Duplicates a particular filter view.', 'properties': {'filterId': {'type': 'integer', 'description': 'The ID of the filter being duplicated.', 'format': 'int32'}}}, 'NamedRange': {'type': 'object', 'id': 'NamedRange', 'description': 'A named range.', 'properties': {'range': {'description': 'The range this represents.', '$ref': 'GridRange'}, 'name': {'type': 'string', 'description': 'The name of the named range.'}, 'namedRangeId': {'type': 'string', 'description': 'The ID of the named range.'}}}, 'DeleteConditionalFormatRuleRequest': {'type': 'object', 'id': 'DeleteConditionalFormatRuleRequest', 'description': "Deletes a conditional format rule at the given index.\nAll subsequent rules' indexes are decremented.", 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet the rule is being deleted from.', 'format': 'int32'}, 'index': {'type': 'integer', 'description': 'The zero-based index of the rule to be deleted.', 'format': 'int32'}}}, 'UpdateBandingRequest': {'type': 'object', 'id': 'UpdateBandingRequest', 'description': 'Updates properties of the supplied banded range.', 'properties': {'bandedRange': {'description': 'The banded range to update with the new properties.', '$ref': 'BandedRange'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `bandedRange` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'BatchUpdateSpreadsheetResponse': {'type': 'object', 'id': 'BatchUpdateSpreadsheetResponse', 'description': 'The reply for batch updating a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'replies': {'type': 'array', 'description': 'The reply of the updates.  This maps 1:1 with the updates, although\nreplies to some requests may be empty.', 'items': {'$ref': 'Response'}}, 'updatedSpreadsheet': {'description': 'The spreadsheet after updates were applied. This is only set if\n[BatchUpdateSpreadsheetRequest.include_spreadsheet_in_response] is `true`.', '$ref': 'Spreadsheet'}}}, 'ChartSpec': {'type': 'object', 'id': 'ChartSpec', 'description': 'The specifications of a chart.', 'properties': {'basicChart': {'description': 'A basic chart specification, can be one of many kinds of charts.\nSee BasicChartType for the list of all\ncharts this supports.', '$ref': 'BasicChartSpec'}, 'hiddenDimensionStrategy': {'description': 'Determines how the charts will use hidden rows or columns.', 'type': 'string', 'enum': ['CHART_HIDDEN_DIMENSION_STRATEGY_UNSPECIFIED', 'SKIP_HIDDEN_ROWS_AND_COLUMNS', 'SKIP_HIDDEN_ROWS', 'SKIP_HIDDEN_COLUMNS', 'SHOW_ALL'], 'enumDescriptions': ['Default value, do not use.', 'Charts will skip hidden rows and columns.', 'Charts will skip hidden rows only.', 'Charts will skip hidden columns only.', 'Charts will not skip any hidden rows or columns.']}, 'pieChart': {'description': 'A pie chart specification.', '$ref': 'PieChartSpec'}, 'title': {'type': 'string', 'description': 'The title of the chart.'}}}, 'DuplicateSheetRequest': {'type': 'object', 'id': 'DuplicateSheetRequest', 'description': 'Duplicates the contents of a sheet.', 'properties': {'newSheetName': {'type': 'string', 'description': 'The name of the new sheet.  If empty, a new name is chosen for you.'}, 'sourceSheetId': {'type': 'integer', 'description': 'The sheet to duplicate.', 'format': 'int32'}, 'insertSheetIndex': {'type': 'integer', 'description': 'The zero-based index where the new sheet should be inserted.\nThe index of all sheets after this are incremented.', 'format': 'int32'}, 'newSheetId': {'type': 'integer', 'description': 'If set, the ID of the new sheet. If not set, an ID is chosen.\nIf set, the ID must not conflict with any existing sheet ID.\nIf set, it must be non-negative.', 'format': 'int32'}}}, 'OverlayPosition': {'type': 'object', 'id': 'OverlayPosition', 'description': 'The location an object is overlaid on top of a grid.', 'properties': {'heightPixels': {'type': 'integer', 'description': 'The height of the object, in pixels. Defaults to 371.', 'format': 'int32'}, 'widthPixels': {'type': 'integer', 'description': 'The width of the object, in pixels. Defaults to 600.', 'format': 'int32'}, 'anchorCell': {'description': 'The cell the object is anchored to.', '$ref': 'GridCoordinate'}, 'offsetXPixels': {'type': 'integer', 'description': 'The horizontal offset, in pixels, that the object is offset\nfrom the anchor cell.', 'format': 'int32'}, 'offsetYPixels': {'type': 'integer', 'description': 'The vertical offset, in pixels, that the object is offset\nfrom the anchor cell.', 'format': 'int32'}}}, 'ClearValuesRequest': {'description': 'The request for clearing a range of values in a spreadsheet.', 'id': 'ClearValuesRequest', 'type': 'object', 'properties': {}}, 'BooleanRule': {'description': 'A rule that may or may not match, depending on the condition.', 'id': 'BooleanRule', 'type': 'object', 'properties': {'condition': {'description': 'The condition of the rule. If the condition evaluates to true,\nthe format will be applied.', '$ref': 'BooleanCondition'}, 'format': {'description': 'The format to apply.\nConditional formatting can only apply a subset of formatting:\nbold, italic,\nstrikethrough,\nforeground color &\nbackground color.', '$ref': 'CellFormat'}}}, 'UpdateValuesResponse': {'type': 'object', 'id': 'UpdateValuesResponse', 'description': 'The response when updating a range of values in a spreadsheet.', 'properties': {'spreadsheetId': {'type': 'string', 'description': 'The spreadsheet the updates were applied to.'}, 'updatedData': {'description': "The values of the cells after updates were applied.\nThis is only included if the request's `includeValuesInResponse` field\nwas `true`.", '$ref': 'ValueRange'}, 'updatedRows': {'type': 'integer', 'description': 'The number of rows where at least one cell in the row was updated.', 'format': 'int32'}, 'updatedRange': {'type': 'string', 'description': 'The range (in A1 notation) that updates were applied to.'}, 'updatedColumns': {'type': 'integer', 'description': 'The number of columns where at least one cell in the column was updated.', 'format': 'int32'}, 'updatedCells': {'type': 'integer', 'description': 'The number of cells updated.', 'format': 'int32'}}}, 'SortRangeRequest': {'description': 'Sorts data in rows based on a sort order per column.', 'id': 'SortRangeRequest', 'type': 'object', 'properties': {'range': {'description': 'The range to sort.', '$ref': 'GridRange'}, 'sortSpecs': {'type': 'array', 'description': 'The sort order per column. Later specifications are used when values\nare equal in the earlier specifications.', 'items': {'$ref': 'SortSpec'}}}}, 'BandedRange': {'type': 'object', 'id': 'BandedRange', 'description': 'A banded (alternating colors) range in a sheet.', 'properties': {'range': {'description': 'The range over which these properties are applied.', '$ref': 'GridRange'}, 'rowProperties': {'description': 'Properties for row bands. These properties will be applied on a row-by-row\nbasis throughout all the rows in the range. At least one of\nrow_properties or column_properties must be specified.', '$ref': 'BandingProperties'}, 'columnProperties': {'description': 'Properties for column bands. These properties will be applied on a column-\nby-column basis throughout all the columns in the range. At least one of\nrow_properties or column_properties must be specified.', '$ref': 'BandingProperties'}, 'bandedRangeId': {'type': 'integer', 'description': 'The id of the banded range.', 'format': 'int32'}}}, 'FilterCriteria': {'type': 'object', 'id': 'FilterCriteria', 'description': 'Criteria for showing/hiding rows in a filter or filter view.', 'properties': {'condition': {'description': 'A condition that must be true for values to be shown.\n(This does not override hiddenValues -- if a value is listed there,\n it will still be hidden.)', '$ref': 'BooleanCondition'}, 'hiddenValues': {'type': 'array', 'description': 'Values that should be hidden.', 'items': {'type': 'string'}}}}, 'ChartSourceRange': {'description': 'Source ranges for a chart.', 'id': 'ChartSourceRange', 'type': 'object', 'properties': {'sources': {'type': 'array', 'description': 'The ranges of data for a series or domain.\nExactly one dimension must have a length of 1,\nand all sources in the list must have the same dimension\nwith length 1.\nThe domain (if it exists) & all series must have the same number\nof source ranges. If using more than one source range, then the source\nrange at a given offset must be contiguous across the domain and series.\n\nFor example, these are valid configurations:\n\n    domain sources: A1:A5\n    series1 sources: B1:B5\n    series2 sources: D6:D10\n\n    domain sources: A1:A5, C10:C12\n    series1 sources: B1:B5, D10:D12\n    series2 sources: C1:C5, E10:E12', 'items': {'$ref': 'GridRange'}}}}, 'SortSpec': {'description': 'A sort order associated with a specific column or row.', 'id': 'SortSpec', 'type': 'object', 'properties': {'dimensionIndex': {'type': 'integer', 'description': 'The dimension the sort should be applied to.', 'format': 'int32'}, 'sortOrder': {'description': 'The order data should be sorted.', 'type': 'string', 'enum': ['SORT_ORDER_UNSPECIFIED', 'ASCENDING', 'DESCENDING'], 'enumDescriptions': ['Default value, do not use this.', 'Sort ascending.', 'Sort descending.']}}}, 'GridProperties': {'type': 'object', 'id': 'GridProperties', 'description': 'Properties of a grid.', 'properties': {'rowCount': {'type': 'integer', 'description': 'The number of rows in the grid.', 'format': 'int32'}, 'frozenColumnCount': {'type': 'integer', 'description': 'The number of columns that are frozen in the grid.', 'format': 'int32'}, 'hideGridlines': {'type': 'boolean', 'description': "True if the grid isn't showing gridlines in the UI."}, 'frozenRowCount': {'type': 'integer', 'description': 'The number of rows that are frozen in the grid.', 'format': 'int32'}, 'columnCount': {'type': 'integer', 'description': 'The number of columns in the grid.', 'format': 'int32'}}}, 'UpdateConditionalFormatRuleRequest': {'type': 'object', 'id': 'UpdateConditionalFormatRuleRequest', 'description': 'Updates a conditional format rule at the given index,\nor moves a conditional format rule to another index.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet of the rule to move.  Required if new_index is set,\nunused otherwise.', 'format': 'int32'}, 'rule': {'description': 'The rule that should replace the rule at the given index.', '$ref': 'ConditionalFormatRule'}, 'index': {'type': 'integer', 'description': 'The zero-based index of the rule that should be replaced or moved.', 'format': 'int32'}, 'newIndex': {'type': 'integer', 'description': 'The zero-based new index the rule should end up at.', 'format': 'int32'}}}, 'AddFilterViewResponse': {'type': 'object', 'id': 'AddFilterViewResponse', 'description': 'The result of adding a filter view.', 'properties': {'filter': {'description': 'The newly added filter view.', '$ref': 'FilterView'}}}, 'PivotGroup': {'description': 'A single grouping (either row or column) in a pivot table.', 'id': 'PivotGroup', 'type': 'object', 'properties': {'valueMetadata': {'type': 'array', 'description': 'Metadata about values in the grouping.', 'items': {'$ref': 'PivotGroupValueMetadata'}}, 'valueBucket': {'description': "The bucket of the opposite pivot group to sort by.\nIf not specified, sorting is alphabetical by this group's values.", '$ref': 'PivotGroupSortValueBucket'}, 'showTotals': {'type': 'boolean', 'description': 'True if the pivot table should include the totals for this grouping.'}, 'sourceColumnOffset': {'type': 'integer', 'description': 'The column offset of the source range that this grouping is based on.\n\nFor example, if the source was `C10:E15`, a `sourceColumnOffset` of `0`\nmeans this group refers to column `C`, whereas the offset `1` would refer\nto column `D`.', 'format': 'int32'}, 'sortOrder': {'description': 'The order the values in this group should be sorted.', 'type': 'string', 'enum': ['SORT_ORDER_UNSPECIFIED', 'ASCENDING', 'DESCENDING'], 'enumDescriptions': ['Default value, do not use this.', 'Sort ascending.', 'Sort descending.']}}}, 'UpdateEmbeddedObjectPositionRequest': {'type': 'object', 'id': 'UpdateEmbeddedObjectPositionRequest', 'description': "Update an embedded object's position (such as a moving or resizing a\nchart or image).", 'properties': {'newPosition': {'description': 'An explicit position to move the embedded object to.\nIf newPosition.sheetId is set,\na new sheet with that ID will be created.\nIf newPosition.newSheet is set to true,\na new sheet will be created with an ID that will be chosen for you.', '$ref': 'EmbeddedObjectPosition'}, 'fields': {'type': 'string', 'description': 'The fields of OverlayPosition\nthat should be updated when setting a new position. Used only if\nnewPosition.overlayPosition\nis set, in which case at least one field must\nbe specified.  The root `newPosition.overlayPosition` is implied and\nshould not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}, 'objectId': {'type': 'integer', 'description': 'The ID of the object to moved.', 'format': 'int32'}}}, 'AddChartRequest': {'type': 'object', 'id': 'AddChartRequest', 'description': 'Adds a chart to a sheet in the spreadsheet.', 'properties': {'chart': {'description': 'The chart that should be added to the spreadsheet, including the position\nwhere it should be placed. The chartId\nfield is optional; if one is not set, an id will be randomly generated. (It\nis an error to specify the ID of a chart that already exists.)', '$ref': 'EmbeddedChart'}}}, 'AppendCellsRequest': {'type': 'object', 'id': 'AppendCellsRequest', 'description': 'Adds new cells after the last row with data in a sheet,\ninserting new rows into the sheet if necessary.', 'properties': {'sheetId': {'type': 'integer', 'description': 'The sheet ID to append the data to.', 'format': 'int32'}, 'rows': {'type': 'array', 'description': 'The data to append.', 'items': {'$ref': 'RowData'}}, 'fields': {'type': 'string', 'description': 'The fields of CellData that should be updated.\nAt least one field must be specified.\nThe root is the CellData; \'row.values.\' should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'BasicChartDomain': {'type': 'object', 'id': 'BasicChartDomain', 'description': 'The domain of a chart.\nFor example, if charting stock prices over time, this would be the date.', 'properties': {'domain': {'description': 'The data of the domain. For example, if charting stock prices over time,\nthis is the data representing the dates.', '$ref': 'ChartData'}}}, 'AddNamedRangeRequest': {'type': 'object', 'id': 'AddNamedRangeRequest', 'description': 'Adds a named range to the spreadsheet.', 'properties': {'namedRange': {'description': 'The named range to add. The namedRangeId\nfield is optional; if one is not set, an id will be randomly generated. (It\nis an error to specify the ID of a range that already exists.)', '$ref': 'NamedRange'}}}, 'ConditionValue': {'type': 'object', 'id': 'ConditionValue', 'description': 'The value of the condition.', 'properties': {'relativeDate': {'description': 'A relative date (based on the current date).\nValid only if the type is\nDATE_BEFORE,\nDATE_AFTER,\nDATE_ON_OR_BEFORE or\nDATE_ON_OR_AFTER.\n\nRelative dates are not supported in data validation.\nThey are supported only in conditional formatting and\nconditional filters.', 'type': 'string', 'enum': ['RELATIVE_DATE_UNSPECIFIED', 'PAST_YEAR', 'PAST_MONTH', 'PAST_WEEK', 'YESTERDAY', 'TODAY', 'TOMORROW'], 'enumDescriptions': ['Default value, do not use.', 'The value is one year before today.', 'The value is one month before today.', 'The value is one week before today.', 'The value is yesterday.', 'The value is today.', 'The value is tomorrow.']}, 'userEnteredValue': {'type': 'string', 'description': 'A value the condition is based on.\nThe value will be parsed as if the user typed into a cell.\nFormulas are supported (and must begin with an `=`).'}}}, 'BandingProperties': {'type': 'object', 'id': 'BandingProperties', 'description': 'Properties referring a single dimension (either row or column). If both\nBandedRange.row_properties and BandedRange.column_properties are\nset, the fill colors are applied to cells according to the following rules:\n\n* header_color and footer_color take priority over band colors.\n* first_band_color takes priority over second_band_color.\n* row_properties takes priority over column_properties.\n\nFor example, the first row color takes priority over the first column\ncolor, but the first column color takes priority over the second row color.\nSimilarly, the row header takes priority over the column header in the\ntop left cell, but the column header takes priority over the first row\ncolor if the row header is not set.', 'properties': {'firstBandColor': {'description': 'The first color that is alternating. (Required)', '$ref': 'Color'}, 'headerColor': {'description': 'The color of the first row or column. If this field is set, the first\nrow or column will be filled with this color and the colors will\nalternate between first_band_color and second_band_color starting\nfrom the second row or column. Otherwise, the first row or column will be\nfilled with first_band_color and the colors will proceed to alternate\nas they normally would.', '$ref': 'Color'}, 'secondBandColor': {'description': 'The second color that is alternating. (Required)', '$ref': 'Color'}, 'footerColor': {'description': 'The color of the last row or column. If this field is not set, the last\nrow or column will be filled with either first_band_color or\nsecond_band_color, depending on the color of the previous row or\ncolumn.', '$ref': 'Color'}}}, 'AddConditionalFormatRuleRequest': {'type': 'object', 'id': 'AddConditionalFormatRuleRequest', 'description': "Adds a new conditional format rule at the given index.\nAll subsequent rules' indexes are incremented.", 'properties': {'rule': {'description': 'The rule to add.', '$ref': 'ConditionalFormatRule'}, 'index': {'type': 'integer', 'description': 'The zero-based index where the rule should be inserted.', 'format': 'int32'}}}, 'CutPasteRequest': {'description': 'Moves data from the source to the destination.', 'id': 'CutPasteRequest', 'type': 'object', 'properties': {'pasteType': {'description': 'What kind of data to paste.  All the source data will be cut, regardless\nof what is pasted.', 'type': 'string', 'enum': ['PASTE_NORMAL', 'PASTE_VALUES', 'PASTE_FORMAT', 'PASTE_NO_BORDERS', 'PASTE_FORMULA', 'PASTE_DATA_VALIDATION', 'PASTE_CONDITIONAL_FORMATTING'], 'enumDescriptions': ['Paste values, formulas, formats, and merges.', 'Paste the values ONLY without formats, formulas, or merges.', 'Paste the format and data validation only.', 'Like PASTE_NORMAL but without borders.', 'Paste the formulas only.', 'Paste the data validation only.', 'Paste the conditional formatting rules only.']}, 'source': {'description': 'The source data to cut.', '$ref': 'GridRange'}, 'destination': {'description': 'The top-left coordinate where the data should be pasted.', '$ref': 'GridCoordinate'}}}, 'UnmergeCellsRequest': {'type': 'object', 'id': 'UnmergeCellsRequest', 'description': 'Unmerges cells in the given range.', 'properties': {'range': {'description': 'The range within which all cells should be unmerged.\nIf the range spans multiple merges, all will be unmerged.\nThe range must not partially span any merge.', '$ref': 'GridRange'}}}, 'UpdateProtectedRangeRequest': {'type': 'object', 'id': 'UpdateProtectedRangeRequest', 'description': 'Updates an existing protected range with the specified\nprotectedRangeId.', 'properties': {'protectedRange': {'description': 'The protected range to update with the new properties.', '$ref': 'ProtectedRange'}, 'fields': {'type': 'string', 'description': 'The fields that should be updated.  At least one field must be specified.\nThe root `protectedRange` is implied and should not be specified.\nA single `"*"` can be used as short-hand for listing every field.', 'format': 'google-fieldmask'}}}, 'BasicChartSpec': {'description': 'The specification for a basic chart.  See BasicChartType for the list\nof charts this supports.', 'id': 'BasicChartSpec', 'type': 'object', 'properties': {'headerCount': {'type': 'integer', 'description': 'The number of rows or columns in the data that are "headers".\nIf not set, Google Sheets will guess how many rows are headers based\non the data.\n\n(Note that BasicChartAxis.title may override the axis title\n inferred from the header values.)', 'format': 'int32'}, 'axis': {'type': 'array', 'description': 'The axis on the chart.', 'items': {'$ref': 'BasicChartAxis'}}, 'domains': {'type': 'array', 'description': 'The domain of data this is charting.\nOnly a single domain is currently supported.', 'items': {'$ref': 'BasicChartDomain'}}, 'series': {'type': 'array', 'description': 'The data this chart is visualizing.', 'items': {'$ref': 'BasicChartSeries'}}, 'chartType': {'description': 'The type of the chart.', 'type': 'string', 'enum': ['BASIC_CHART_TYPE_UNSPECIFIED', 'BAR', 'LINE', 'AREA', 'COLUMN', 'SCATTER', 'COMBO'], 'enumDescriptions': ['Default value, do not use.', 'A <a href="/chart/interactive/docs/gallery/barchart">bar chart</a>.', 'A <a href="/chart/interactive/docs/gallery/linechart">line chart</a>.', 'An <a href="/chart/interactive/docs/gallery/areachart">area chart</a>.', 'A <a href="/chart/interactive/docs/gallery/columnchart">column chart</a>.', 'A <a href="/chart/interactive/docs/gallery/scatterchart">scatter chart</a>.', 'A <a href="/chart/interactive/docs/gallery/combochart">combo chart</a>.']}, 'legendPosition': {'description': 'The position of the chart legend.', 'type': 'string', 'enum': ['BASIC_CHART_LEGEND_POSITION_UNSPECIFIED', 'BOTTOM_LEGEND', 'LEFT_LEGEND', 'RIGHT_LEGEND', 'TOP_LEGEND', 'NO_LEGEND'], 'enumDescriptions': ['Default value, do not use.', 'The legend is rendered on the bottom of the chart.', 'The legend is rendered on the left of the chart.', 'The legend is rendered on the right of the chart.', 'The legend is rendered on the top of the chart.', 'No legend is rendered.']}}}, 'DeleteSheetRequest': {'description': 'Deletes the requested sheet.', 'id': 'DeleteSheetRequest', 'type': 'object', 'properties': {'sheetId': {'type': 'integer', 'description': 'The ID of the sheet to delete.', 'format': 'int32'}}}, 'DataValidationRule': {'type': 'object', 'id': 'DataValidationRule', 'description': 'A data validation rule.', 'properties': {'showCustomUi': {'type': 'boolean', 'description': 'True if the UI should be customized based on the kind of condition.\nIf true, "List" conditions will show a dropdown.'}, 'strict': {'type': 'boolean', 'description': 'True if invalid data should be rejected.'}, 'condition': {'description': 'The condition that data in the cell must match.', '$ref': 'BooleanCondition'}, 'inputMessage': {'type': 'string', 'description': 'A message to show the user when adding data to the cell.'}}}, 'DeleteNamedRangeRequest': {'type': 'object', 'id': 'DeleteNamedRangeRequest', 'description': 'Removes the named range with the given ID from the spreadsheet.', 'properties': {'namedRangeId': {'type': 'string', 'description': 'The ID of the named range to delete.'}}}, 'ErrorValue': {'type': 'object', 'id': 'ErrorValue', 'description': 'An error in a cell.', 'properties': {'type': {'description': 'The type of error.', 'type': 'string', 'enum': ['ERROR_TYPE_UNSPECIFIED', 'ERROR', 'NULL_VALUE', 'DIVIDE_BY_ZERO', 'VALUE', 'REF', 'NAME', 'NUM', 'N_A', 'LOADING'], 'enumDescriptions': ['The default error type, do not use this.', 'Corresponds to the `#ERROR!` error.', 'Corresponds to the `#NULL!` error.', 'Corresponds to the `#DIV/0` error.', 'Corresponds to the `#VALUE!` error.', 'Corresponds to the `#REF!` error.', 'Corresponds to the `#NAME?` error.', 'Corresponds to the `#NUM`! error.', 'Corresponds to the `#N/A` error.', 'Corresponds to the `Loading...` state.']}, 'message': {'type': 'string', 'description': "A message with more information about the error\n(in the spreadsheet's locale)."}}}, 'AddFilterViewRequest': {'type': 'object', 'id': 'AddFilterViewRequest', 'description': 'Adds a filter view.', 'properties': {'filter': {'description': 'The filter to add. The filterViewId\nfield is optional; if one is not set, an id will be randomly generated. (It\nis an error to specify the ID of a filter that already exists.)', '$ref': 'FilterView'}}}, 'TextFormatRun': {'type': 'object', 'id': 'TextFormatRun', 'description': 'A run of a text format. The format of this run continues until the start\nindex of the next run.\nWhen updating, all fields must be set.', 'properties': {'format': {'description': "The format of this run.  Absent values inherit the cell's format.", '$ref': 'TextFormat'}, 'startIndex': {'type': 'integer', 'description': 'The character index where this run starts.', 'format': 'int32'}}}, 'Request': {'type': 'object', 'id': 'Request', 'description': 'A single kind of update to apply to a spreadsheet.', 'properties': {'insertRange': {'description': 'Inserts new cells in a sheet, shifting the existing cells.', '$ref': 'InsertRangeRequest'}, 'insertDimension': {'description': 'Inserts new rows or columns in a sheet.', '$ref': 'InsertDimensionRequest'}, 'updateConditionalFormatRule': {'description': 'Updates an existing conditional format rule.', '$ref': 'UpdateConditionalFormatRuleRequest'}, 'addBanding': {'description': 'Adds a new banded range', '$ref': 'AddBandingRequest'}, 'mergeCells': {'description': 'Merges cells together.', '$ref': 'MergeCellsRequest'}, 'deleteDimension': {'description': 'Deletes rows or columns in a sheet.', '$ref': 'DeleteDimensionRequest'}, 'addFilterView': {'description': 'Adds a filter view.', '$ref': 'AddFilterViewRequest'}, 'updateSheetProperties': {'description': "Updates a sheet's properties.", '$ref': 'UpdateSheetPropertiesRequest'}, 'setBasicFilter': {'description': 'Sets the basic filter on a sheet.', '$ref': 'SetBasicFilterRequest'}, 'clearBasicFilter': {'description': 'Clears the basic filter on a sheet.', '$ref': 'ClearBasicFilterRequest'}, 'copyPaste': {'description': 'Copies data from one area and pastes it to another.', '$ref': 'CopyPasteRequest'}, 'appendCells': {'description': 'Appends cells after the last row with data in a sheet.', '$ref': 'AppendCellsRequest'}, 'deleteNamedRange': {'description': 'Deletes a named range.', '$ref': 'DeleteNamedRangeRequest'}, 'deleteFilterView': {'description': 'Deletes a filter view from a sheet.', '$ref': 'DeleteFilterViewRequest'}, 'addChart': {'description': 'Adds a chart.', '$ref': 'AddChartRequest'}, 'updateCells': {'description': 'Updates many cells at once.', '$ref': 'UpdateCellsRequest'}, 'updateBanding': {'description': 'Updates a banded range', '$ref': 'UpdateBandingRequest'}, 'addSheet': {'description': 'Adds a sheet.', '$ref': 'AddSheetRequest'}, 'addProtectedRange': {'description': 'Adds a protected range.', '$ref': 'AddProtectedRangeRequest'}, 'pasteData': {'description': 'Pastes data (HTML or delimited) into a sheet.', '$ref': 'PasteDataRequest'}, 'updateSpreadsheetProperties': {'description': "Updates the spreadsheet's properties.", '$ref': 'UpdateSpreadsheetPropertiesRequest'}, 'updateProtectedRange': {'description': 'Updates a protected range.', '$ref': 'UpdateProtectedRangeRequest'}, 'setDataValidation': {'description': 'Sets data validation for one or more cells.', '$ref': 'SetDataValidationRequest'}, 'deleteEmbeddedObject': {'description': 'Deletes an embedded object (e.g, chart, image) in a sheet.', '$ref': 'DeleteEmbeddedObjectRequest'}, 'deleteSheet': {'description': 'Deletes a sheet.', '$ref': 'DeleteSheetRequest'}, 'cutPaste': {'description': 'Cuts data from one area and pastes it to another.', '$ref': 'CutPasteRequest'}, 'deleteRange': {'description': 'Deletes a range of cells from a sheet, shifting the remaining cells.', '$ref': 'DeleteRangeRequest'}, 'autoFill': {'description': 'Automatically fills in more data based on existing data.', '$ref': 'AutoFillRequest'}, 'addConditionalFormatRule': {'description': 'Adds a new conditional format rule.', '$ref': 'AddConditionalFormatRuleRequest'}, 'updateNamedRange': {'description': 'Updates a named range.', '$ref': 'UpdateNamedRangeRequest'}, 'deleteProtectedRange': {'description': 'Deletes a protected range.', '$ref': 'DeleteProtectedRangeRequest'}, 'findReplace': {'description': 'Finds and replaces occurrences of some text with other text.', '$ref': 'FindReplaceRequest'}, 'updateFilterView': {'description': 'Updates the properties of a filter view.', '$ref': 'UpdateFilterViewRequest'}, 'moveDimension': {'description': 'Moves rows or columns to another location in a sheet.', '$ref': 'MoveDimensionRequest'}, 'repeatCell': {'description': 'Repeats a single cell across a range.', '$ref': 'RepeatCellRequest'}, 'deleteConditionalFormatRule': {'description': 'Deletes an existing conditional format rule.', '$ref': 'DeleteConditionalFormatRuleRequest'}, 'deleteBanding': {'description': 'Removes a banded range', '$ref': 'DeleteBandingRequest'}, 'sortRange': {'description': 'Sorts data in a range.', '$ref': 'SortRangeRequest'}, 'unmergeCells': {'description': 'Unmerges merged cells.', '$ref': 'UnmergeCellsRequest'}, 'updateDimensionProperties': {'description': "Updates dimensions' properties.", '$ref': 'UpdateDimensionPropertiesRequest'}, 'textToColumns': {'description': 'Converts a column of text into many columns of text.', '$ref': 'TextToColumnsRequest'}, 'updateBorders': {'description': 'Updates the borders in a range of cells.', '$ref': 'UpdateBordersRequest'}, 'duplicateSheet': {'description': 'Duplicates a sheet.', '$ref': 'DuplicateSheetRequest'}, 'duplicateFilterView': {'description': 'Duplicates a filter view.', '$ref': 'DuplicateFilterViewRequest'}, 'updateEmbeddedObjectPosition': {'description': "Updates an embedded object's (e.g. chart, image) position.", '$ref': 'UpdateEmbeddedObjectPositionRequest'}, 'appendDimension': {'description': 'Appends dimensions to the end of a sheet.', '$ref': 'AppendDimensionRequest'}, 'addNamedRange': {'description': 'Adds a named range.', '$ref': 'AddNamedRangeRequest'}, 'autoResizeDimensions': {'description': 'Automatically resizes one or more dimensions based on the contents\nof the cells in that dimension.', '$ref': 'AutoResizeDimensionsRequest'}, 'updateChartSpec': {'description': "Updates a chart's specifications.", '$ref': 'UpdateChartSpecRequest'}}}, 'PivotFilterCriteria': {'type': 'object', 'id': 'PivotFilterCriteria', 'description': 'Criteria for showing/hiding rows in a pivot table.', 'properties': {'visibleValues': {'type': 'array', 'description': 'Values that should be included.  Values not listed here are excluded.', 'items': {'type': 'string'}}}}}, 'revision': '20170126', 'auth': {'oauth2': {'scopes': {'https://www.googleapis.com/auth/drive': {'description': 'View and manage the files in your Google Drive'}, 'https://www.googleapis.com/auth/spreadsheets': {'description': 'View and manage your spreadsheets in Google Drive'}, 'https://www.googleapis.com/auth/drive.readonly': {'description': 'View the files in your Google Drive'}, 'https://www.googleapis.com/auth/spreadsheets.readonly': {'description': 'View your Google Spreadsheets'}}}}, 'canonicalName': 'Sheets', 'ownerName': 'Google', 'id': 'sheets:v4', 'documentationLink': 'https://developers.google.com/sheets/', 'parameters': {'oauth_token': {'type': 'string', 'description': 'OAuth 2.0 token for the current user.', 'location': 'query'}, 'pp': {'type': 'boolean', 'default': 'true', 'description': 'Pretty-print response.', 'location': 'query'}, 'uploadType': {'type': 'string', 'description': 'Legacy upload protocol for media (e.g. "media", "multipart").', 'location': 'query'}, 'upload_protocol': {'type': 'string', 'description': 'Upload protocol for media (e.g. "raw", "multipart").', 'location': 'query'}, 'alt': {'type': 'string', 'enum': ['json', 'media', 'proto'], 'description': 'Data format for response.', 'default': 'json', 'enumDescriptions': ['Responses with Content-Type of application/json', 'Media download with context-dependent Content-Type', 'Responses with Content-Type of application/x-protobuf'], 'location': 'query'}, 'callback': {'type': 'string', 'description': 'JSONP', 'location': 'query'}, 'key': {'type': 'string', 'description': 'API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.', 'location': 'query'}, 'access_token': {'type': 'string', 'description': 'OAuth access token.', 'location': 'query'}, 'quotaUser': {'type': 'string', 'description': 'Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.', 'location': 'query'}, 'fields': {'type': 'string', 'description': 'Selector specifying which fields to include in a partial response.', 'location': 'query'}, 'bearer_token': {'type': 'string', 'description': 'OAuth bearer token.', 'location': 'query'}, '$.xgafv': {'description': 'V1 error format.', 'type': 'string', 'enum': ['1', '2'], 'enumDescriptions': ['v1 error format', 'v2 error format'], 'location': 'query'}, 'prettyPrint': {'type': 'boolean', 'default': 'true', 'description': 'Returns response with indentations and line breaks.', 'location': 'query'}}, 'resources': {'spreadsheets': {'methods': {'batchUpdate': {'response': {'$ref': 'BatchUpdateSpreadsheetResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}:batchUpdate', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'BatchUpdateSpreadsheetRequest'}, 'parameterOrder': ['spreadsheetId'], 'description': 'Applies one or more updates to the spreadsheet.\n\nEach request is validated before\nbeing applied. If any request is not valid then the entire request will\nfail and nothing will be applied.\n\nSome requests have replies to\ngive you some information about how\nthey are applied. The replies will mirror the requests.  For example,\nif you applied 4 updates and the 3rd one had a reply, then the\nresponse will have 2 empty replies, the actual reply, and another empty\nreply, in that order.\n\nDue to the collaborative nature of spreadsheets, it is not guaranteed that\nthe spreadsheet will reflect exactly your changes after this completes,\nhowever it is guaranteed that the updates in the request will be\napplied together atomically. Your changes may be altered with respect to\ncollaborator changes. If there are no collaborators, the spreadsheet\nshould reflect your changes.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The spreadsheet to apply the updates to.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.batchUpdate', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}:batchUpdate'}, 'get': {'response': {'$ref': 'Spreadsheet'}, 'path': 'v4/spreadsheets/{spreadsheetId}', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/drive.readonly', 'https://www.googleapis.com/auth/spreadsheets', 'https://www.googleapis.com/auth/spreadsheets.readonly'], 'httpMethod': 'GET', 'description': 'Returns the spreadsheet at the given ID.\nThe caller must specify the spreadsheet ID.\n\nBy default, data within grids will not be returned.\nYou can include grid data one of two ways:\n\n* Specify a field mask listing your desired fields using the `fields` URL\nparameter in HTTP\n\n* Set the includeGridData\nURL parameter to true.  If a field mask is set, the `includeGridData`\nparameter is ignored\n\nFor large spreadsheets, it is recommended to retrieve only the specific\nfields of the spreadsheet that you want.\n\nTo retrieve only subsets of the spreadsheet, use the\nranges URL parameter.\nMultiple ranges can be specified.  Limiting the range will\nreturn only the portions of the spreadsheet that intersect the requested\nranges. Ranges are specified using A1 notation.', 'parameters': {'ranges': {'type': 'string', 'repeated': True, 'description': 'The ranges to retrieve from the spreadsheet.', 'location': 'query'}, 'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The spreadsheet to request.', 'location': 'path'}, 'includeGridData': {'type': 'boolean', 'description': 'True if grid data should be returned.\nThis parameter is ignored if a field mask was set in the request.', 'location': 'query'}}, 'id': 'sheets.spreadsheets.get', 'parameterOrder': ['spreadsheetId'], 'flatPath': 'v4/spreadsheets/{spreadsheetId}'}, 'create': {'response': {'$ref': 'Spreadsheet'}, 'path': 'v4/spreadsheets', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'Spreadsheet'}, 'parameterOrder': [], 'description': 'Creates a spreadsheet, returning the newly created spreadsheet.', 'parameters': {}, 'id': 'sheets.spreadsheets.create', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets'}}, 'resources': {'values': {'methods': {'batchUpdate': {'response': {'$ref': 'BatchUpdateValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values:batchUpdate', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'BatchUpdateValuesRequest'}, 'parameterOrder': ['spreadsheetId'], 'description': 'Sets values in one or more ranges of a spreadsheet.\nThe caller must specify the spreadsheet ID,\na valueInputOption, and one or more\nValueRanges.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to update.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.values.batchUpdate', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values:batchUpdate'}, 'clear': {'response': {'$ref': 'ClearValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values/{range}:clear', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'ClearValuesRequest'}, 'parameterOrder': ['spreadsheetId', 'range'], 'description': 'Clears values from a spreadsheet.\nThe caller must specify the spreadsheet ID and range.\nOnly values are cleared -- all other properties of the cell (such as\nformatting, data validation, etc..) are kept.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to update.', 'location': 'path'}, 'range': {'type': 'string', 'required': True, 'description': 'The A1 notation of the values to clear.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.values.clear', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values/{range}:clear'}, 'update': {'response': {'$ref': 'UpdateValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values/{range}', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'ValueRange'}, 'parameterOrder': ['spreadsheetId', 'range'], 'description': 'Sets values in a range of a spreadsheet.\nThe caller must specify the spreadsheet ID, range, and\na valueInputOption.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to update.', 'location': 'path'}, 'valueInputOption': {'type': 'string', 'enum': ['INPUT_VALUE_OPTION_UNSPECIFIED', 'RAW', 'USER_ENTERED'], 'description': 'How the input data should be interpreted.', 'location': 'query'}, 'responseDateTimeRenderOption': {'type': 'string', 'enum': ['SERIAL_NUMBER', 'FORMATTED_STRING'], 'description': 'Determines how dates, times, and durations in the response should be\nrendered. This is ignored if response_value_render_option is\nFORMATTED_VALUE.\nThe default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].', 'location': 'query'}, 'includeValuesInResponse': {'type': 'boolean', 'description': 'Determines if the update response should include the values\nof the cells that were updated. By default, responses\ndo not include the updated values.\nIf the range to write was larger than than the range actually written,\nthe response will include all values in the requested range (excluding\ntrailing empty rows and columns).', 'location': 'query'}, 'range': {'type': 'string', 'required': True, 'description': 'The A1 notation of the values to update.', 'location': 'path'}, 'responseValueRenderOption': {'type': 'string', 'enum': ['FORMATTED_VALUE', 'UNFORMATTED_VALUE', 'FORMULA'], 'description': 'Determines how values in the response should be rendered.\nThe default render option is ValueRenderOption.FORMATTED_VALUE.', 'location': 'query'}}, 'id': 'sheets.spreadsheets.values.update', 'httpMethod': 'PUT', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values/{range}'}, 'append': {'response': {'$ref': 'AppendValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values/{range}:append', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'ValueRange'}, 'parameterOrder': ['spreadsheetId', 'range'], 'description': 'Appends values to a spreadsheet. The input range is used to search for\nexisting data and find a "table" within that range. Values will be\nappended to the next row of the table, starting with the first column of\nthe table. See the\n[guide](/sheets/guides/values#appending_values)\nand\n[sample code](/sheets/samples/writing#append_values)\nfor specific details of how tables are detected and data is appended.\n\nThe caller must specify the spreadsheet ID, range, and\na valueInputOption.  The `valueInputOption` only\ncontrols how the input data will be added to the sheet (column-wise or\nrow-wise), it does not influence what cell the data starts being written\nto.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to update.', 'location': 'path'}, 'valueInputOption': {'type': 'string', 'enum': ['INPUT_VALUE_OPTION_UNSPECIFIED', 'RAW', 'USER_ENTERED'], 'description': 'How the input data should be interpreted.', 'location': 'query'}, 'includeValuesInResponse': {'type': 'boolean', 'description': 'Determines if the update response should include the values\nof the cells that were appended. By default, responses\ndo not include the updated values.', 'location': 'query'}, 'responseDateTimeRenderOption': {'type': 'string', 'enum': ['SERIAL_NUMBER', 'FORMATTED_STRING'], 'description': 'Determines how dates, times, and durations in the response should be\nrendered. This is ignored if response_value_render_option is\nFORMATTED_VALUE.\nThe default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].', 'location': 'query'}, 'responseValueRenderOption': {'type': 'string', 'enum': ['FORMATTED_VALUE', 'UNFORMATTED_VALUE', 'FORMULA'], 'description': 'Determines how values in the response should be rendered.\nThe default render option is ValueRenderOption.FORMATTED_VALUE.', 'location': 'query'}, 'range': {'type': 'string', 'required': True, 'description': 'The A1 notation of a range to search for a logical table of data.\nValues will be appended after the last row of the table.', 'location': 'path'}, 'insertDataOption': {'type': 'string', 'enum': ['OVERWRITE', 'INSERT_ROWS'], 'description': 'How the input data should be inserted.', 'location': 'query'}}, 'id': 'sheets.spreadsheets.values.append', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values/{range}:append'}, 'get': {'response': {'$ref': 'ValueRange'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values/{range}', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/drive.readonly', 'https://www.googleapis.com/auth/spreadsheets', 'https://www.googleapis.com/auth/spreadsheets.readonly'], 'httpMethod': 'GET', 'description': 'Returns a range of values from a spreadsheet.\nThe caller must specify the spreadsheet ID and a range.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to retrieve data from.', 'location': 'path'}, 'valueRenderOption': {'type': 'string', 'enum': ['FORMATTED_VALUE', 'UNFORMATTED_VALUE', 'FORMULA'], 'description': 'How values should be represented in the output.\nThe default render option is ValueRenderOption.FORMATTED_VALUE.', 'location': 'query'}, 'range': {'type': 'string', 'required': True, 'description': 'The A1 notation of the values to retrieve.', 'location': 'path'}, 'majorDimension': {'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'description': 'The major dimension that results should use.\n\nFor example, if the spreadsheet data is: `A1=1,B1=2,A2=3,B2=4`,\nthen requesting `range=A1:B2,majorDimension=ROWS` will return\n`[[1,2],[3,4]]`,\nwhereas requesting `range=A1:B2,majorDimension=COLUMNS` will return\n`[[1,3],[2,4]]`.', 'location': 'query'}, 'dateTimeRenderOption': {'type': 'string', 'enum': ['SERIAL_NUMBER', 'FORMATTED_STRING'], 'description': 'How dates, times, and durations should be represented in the output.\nThis is ignored if value_render_option is\nFORMATTED_VALUE.\nThe default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].', 'location': 'query'}}, 'id': 'sheets.spreadsheets.values.get', 'parameterOrder': ['spreadsheetId', 'range'], 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values/{range}'}, 'batchClear': {'response': {'$ref': 'BatchClearValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values:batchClear', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'BatchClearValuesRequest'}, 'parameterOrder': ['spreadsheetId'], 'description': 'Clears one or more ranges of values from a spreadsheet.\nThe caller must specify the spreadsheet ID and one or more ranges.\nOnly values are cleared -- all other properties of the cell (such as\nformatting, data validation, etc..) are kept.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to update.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.values.batchClear', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values:batchClear'}, 'batchGet': {'response': {'$ref': 'BatchGetValuesResponse'}, 'path': 'v4/spreadsheets/{spreadsheetId}/values:batchGet', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/drive.readonly', 'https://www.googleapis.com/auth/spreadsheets', 'https://www.googleapis.com/auth/spreadsheets.readonly'], 'httpMethod': 'GET', 'description': 'Returns one or more ranges of values from a spreadsheet.\nThe caller must specify the spreadsheet ID and one or more ranges.', 'parameters': {'valueRenderOption': {'type': 'string', 'enum': ['FORMATTED_VALUE', 'UNFORMATTED_VALUE', 'FORMULA'], 'description': 'How values should be represented in the output.\nThe default render option is ValueRenderOption.FORMATTED_VALUE.', 'location': 'query'}, 'dateTimeRenderOption': {'type': 'string', 'enum': ['SERIAL_NUMBER', 'FORMATTED_STRING'], 'description': 'How dates, times, and durations should be represented in the output.\nThis is ignored if value_render_option is\nFORMATTED_VALUE.\nThe default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].', 'location': 'query'}, 'majorDimension': {'type': 'string', 'enum': ['DIMENSION_UNSPECIFIED', 'ROWS', 'COLUMNS'], 'description': 'The major dimension that results should use.\n\nFor example, if the spreadsheet data is: `A1=1,B1=2,A2=3,B2=4`,\nthen requesting `range=A1:B2,majorDimension=ROWS` will return\n`[[1,2],[3,4]]`,\nwhereas requesting `range=A1:B2,majorDimension=COLUMNS` will return\n`[[1,3],[2,4]]`.', 'location': 'query'}, 'ranges': {'type': 'string', 'repeated': True, 'description': 'The A1 notation of the values to retrieve.', 'location': 'query'}, 'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet to retrieve data from.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.values.batchGet', 'parameterOrder': ['spreadsheetId'], 'flatPath': 'v4/spreadsheets/{spreadsheetId}/values:batchGet'}}}, 'sheets': {'methods': {'copyTo': {'response': {'$ref': 'SheetProperties'}, 'path': 'v4/spreadsheets/{spreadsheetId}/sheets/{sheetId}:copyTo', 'scopes': ['https://www.googleapis.com/auth/drive', 'https://www.googleapis.com/auth/spreadsheets'], 'request': {'$ref': 'CopySheetToAnotherSpreadsheetRequest'}, 'parameterOrder': ['spreadsheetId', 'sheetId'], 'description': 'Copies a single sheet from a spreadsheet to another spreadsheet.\nReturns the properties of the newly created sheet.', 'parameters': {'spreadsheetId': {'type': 'string', 'required': True, 'description': 'The ID of the spreadsheet containing the sheet to copy.', 'location': 'path'}, 'sheetId': {'format': 'int32', 'type': 'integer', 'required': True, 'description': 'The ID of the sheet to copy.', 'location': 'path'}}, 'id': 'sheets.spreadsheets.sheets.copyTo', 'httpMethod': 'POST', 'flatPath': 'v4/spreadsheets/{spreadsheetId}/sheets/{sheetId}:copyTo'}}}}}}, 'protocol': 'rest', 'ownerDomain': 'google.com', 'title': 'Google Sheets API', 'kind': 'discovery#restDescription', 'servicePath': '', 'icons': {'x16': 'http://www.google.com/images/icons/product/search-16.gif', 'x32': 'http://www.google.com/images/icons/product/search-32.gif'}, 'description': 'Reads and writes Google Sheets.', 'rootUrl': 'https://sheets.googleapis.com/', 'name': 'sheets'}
